=== added directory 'plugin/memcached_functions'
=== added file 'plugin/memcached_functions/memc_add.cc'
--- plugin/memcached_functions/memc_add.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_add.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,78 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_add.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+int64_t MemcachedAdd::val_int()
+{
+  memcached_return rc;
+  time_t expiration= 0;
+  String *key;
+  String *res;
+  null_value= false;
+
+  if ((arg_count != 2 && arg_count != 3) ||
+      ! (key= args[0]->val_str(&value)) ||
+      ! (res= args[1]->val_str(&value)) ||
+      ! memc)
+  {
+    return 0;
+  }
+
+  if (arg_count == 3)
+  {
+    String *tmp_exp= args[2]->val_str(&value);;
+
+    expiration= (time_t)atoi(tmp_exp->c_ptr());
+  }
+
+  rc= memcached_add(memc, key->c_ptr(), key->length(),
+                    res->c_ptr(), res->length(),
+                    expiration, (uint16_t) 0);
+
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    return 0;
+  }
+
+  return 1;
+}

=== added file 'plugin/memcached_functions/memc_add.h'
--- plugin/memcached_functions/memc_add.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_add.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,77 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_ADD_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_ADD_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/item/func.h>
+#include <string>
+
+/**
+  * @file
+  * memc_add UDF
+*/
+class MemcachedAdd: public Item_int_func
+{
+  String value;
+  String failure_buff;
+public:
+  MemcachedAdd()
+    :
+      Item_int_func(),
+      failure_buff("0", &my_charset_bin)
+  {}
+
+  const char *func_name() const
+  {
+    return "memc_add";
+  }
+
+  int64_t val_int();
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+/*
+ * memc_add takes 2 or 3 arguments
+*/
+  bool check_argument_count(int n)
+  {
+    return ((n == 2 || n == 3));
+  }
+
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_ADD_H */

=== added file 'plugin/memcached_functions/memc_add_by_key.cc'
--- plugin/memcached_functions/memc_add_by_key.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_add_by_key.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,82 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_add_by_key.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+int64_t MemcachedAddByKey::val_int()
+{
+  memcached_return rc;
+  time_t expiration= 0;
+  String *master_key;
+  String *key;
+  String *res;
+  null_value= false;
+
+  if ((arg_count != 3 && arg_count != 4) ||
+      ! (master_key= args[0]->val_str(&value)) ||
+      ! (key= args[1]->val_str(&value)) ||
+      ! (res= args[2]->val_str(&value)) ||
+      ! memc)
+  {
+    return 0;
+  }
+
+  if (arg_count == 4)
+  {
+    String *tmp_exp= args[3]->val_str(&value);;
+
+    expiration= (time_t)atoi(tmp_exp->c_ptr());
+  }
+
+  rc= memcached_add_by_key(memc,
+                           master_key->c_ptr(), master_key->length(),
+                           key->c_ptr(), key->length(),
+                           res->c_ptr(), res->length(),
+                           expiration, (uint16_t) 0);
+
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    return 0;
+  }
+
+  return 1;
+}

=== added file 'plugin/memcached_functions/memc_add_by_key.h'
--- plugin/memcached_functions/memc_add_by_key.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_add_by_key.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,78 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_ADD_BY_KEY_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_ADD_BY_KEY_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/item/func.h>
+#include <string>
+
+
+/**
+  * @file
+  * The memc_add_by_key UDF
+*/
+class MemcachedAddByKey : public Item_int_func
+{
+  String value;
+  String failure_buff;
+public:
+  MemcachedAddByKey()
+    :
+      Item_int_func(),
+      failure_buff("0", &my_charset_bin)
+  {}
+
+  const char *func_name() const
+  {
+    return "memc_add_by_key";
+  }
+
+  int64_t val_int();
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+/*
+ * This UDF takes 3 or 4 arguments
+*/
+
+  bool check_argument_count(int n)
+  {
+    return ((n == 3 || n == 4));
+  }
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_SET_BY_KEY_H */

=== added file 'plugin/memcached_functions/memc_append.cc'
--- plugin/memcached_functions/memc_append.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_append.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,75 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_append.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+int64_t MemcachedAppend::val_int()
+{
+  memcached_return rc;
+  time_t expiration= 0;
+  String *key;
+  String *res;
+  null_value= false;
+
+  if ((arg_count != 2 && arg_count != 3) ||
+      !(key= args[0]->val_str(&value)) ||
+      !(res= args[1]->val_str(&value)) ||
+      !memc)
+  {
+    return 0;
+  }
+  if (arg_count == 3)
+  {
+    String *tmp_exp= args[2]->val_str(&value);
+    expiration= (time_t)atoi(tmp_exp->c_ptr());
+  }
+
+  rc= memcached_append(memc, key->c_ptr(), key->length(),
+                       res->c_ptr(), res->length(),
+                       expiration, (uint16_t) 0);
+
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    return 0;
+  }
+
+  return 1;
+}

=== added file 'plugin/memcached_functions/memc_append.h'
--- plugin/memcached_functions/memc_append.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_append.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,80 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_APPEND_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_APPEND_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/item/func.h>
+#include <string>
+
+
+using namespace std;
+
+/**
+  * @file
+  * The memc_append UDF
+  */
+class MemcachedAppend : public Item_int_func
+{
+  String value;
+  String failure_buff;
+public:
+  MemcachedAppend()
+    :
+      Item_int_func(),
+      failure_buff("failure ...", &my_charset_bin)
+  {}
+
+  const char *func_name() const
+  {
+    return "memc_append";
+  }
+
+  int64_t val_int();
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+/*
+ * This UDF takes 2 or 3 arguments
+ */
+  bool check_argument_count(int n)
+  {
+    return ((n == 2 || n == 3));
+  }
+
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_APPEND_H */

=== added file 'plugin/memcached_functions/memc_append_by_key.cc'
--- plugin/memcached_functions/memc_append_by_key.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_append_by_key.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,80 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_append_by_key.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+int64_t MemcachedAppendByKey::val_int()
+{
+  memcached_return rc;
+  time_t expiration= 0;
+  String *master_key;
+  String *key;
+  String *res;
+  null_value= false;
+
+  if ((arg_count != 3 && arg_count != 4) ||
+      ! (master_key=  args[0]->val_str(&value)) ||
+      ! (key=         args[1]->val_str(&value)) ||
+      ! (res=         args[2]->val_str(&value)) ||
+      ! memc)
+  {
+    return 0;
+  }
+  if (arg_count == 4)
+  {
+    String *tmp_exp= args[3]->val_str(&value);;
+    expiration= (time_t)atoi(tmp_exp->c_ptr());
+  }
+
+  rc= memcached_append_by_key(memc,
+                              master_key->c_ptr(),
+                              master_key->length(),
+                              key->c_ptr(), key->length(),
+                              res->c_ptr(), res->length(),
+                              expiration, (uint16_t) 0);
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    return 0;
+  }
+
+  return 1;
+}

=== added file 'plugin/memcached_functions/memc_append_by_key.h'
--- plugin/memcached_functions/memc_append_by_key.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_append_by_key.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,77 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_APPEND_BY_KEY_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_APPEND_BY_KEY_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/item/func.h>
+#include <string>
+
+using namespace std;
+
+/**
+  * @file
+      The memc_append_by_key UDF
+*/
+class MemcachedAppendByKey : public Item_int_func
+{
+  String failure_buff;
+  String value;
+public:
+  MemcachedAppendByKey()
+    :
+      Item_int_func(),
+      failure_buff("failure ...", &my_charset_bin)
+  {}
+
+  const char *func_name() const
+  {
+    return "memc_append_by_key";
+  }
+
+  int64_t val_int();
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+  bool check_argument_count(int n)
+  {
+    return ((n == 3 || n == 4));
+  }
+
+
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_APPEND_BY_KEY_H */

=== added file 'plugin/memcached_functions/memc_behavior_get.cc'
--- plugin/memcached_functions/memc_behavior_get.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_behavior_get.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,151 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/item/func.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_behavior_get.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+#include <algorithm>
+
+using namespace std;
+
+void MemcachedBehaviorGet::setFailureString(const char *error)
+{
+  size_t size= strlen(error);
+  failure_buff.realloc(size);
+  failure_buff.length(size);
+  memcpy(failure_buff.ptr(), error, size);
+}
+
+String *MemcachedBehaviorGet::val_str(String *str)
+{
+  memcached_behavior mbehavior;
+  uint64_t isetting;
+  map<const string, memcached_behavior>::iterator it;
+  String *tmp_behavior;
+
+  if (arg_count != 1 ||
+      ! (tmp_behavior= args[0]->val_str(str)) ||
+      ! memc)
+  {
+    setFailureString("USAGE: memc_behavior_get('<behavior type>')");
+    return &failure_buff;
+  }
+
+  string behavior(tmp_behavior->c_ptr());
+
+  /*
+   * We don't want the user to have to type in all input in upper
+   * case so we transform the input strings to upper case here.
+   */
+  std::transform(behavior.begin(), behavior.end(),
+                 behavior.begin(), ::toupper);
+
+  it = behavior_map.find(behavior);
+  if (it == behavior_map.end()) 
+  {
+    setFailureString("UNKNOWN BEHAVIOR TYPE!");
+    return &failure_buff;
+  }
+	
+  mbehavior= behavior_map[behavior];
+
+  isetting= memcached_behavior_get(memc, mbehavior);
+
+  switch (mbehavior)
+  {
+  case MEMCACHED_BEHAVIOR_SUPPORT_CAS:
+  case MEMCACHED_BEHAVIOR_NO_BLOCK:
+  case MEMCACHED_BEHAVIOR_BUFFER_REQUESTS:
+  case MEMCACHED_BEHAVIOR_USER_DATA:
+  case MEMCACHED_BEHAVIOR_SORT_HOSTS:
+  case MEMCACHED_BEHAVIOR_VERIFY_KEY:
+  case MEMCACHED_BEHAVIOR_TCP_NODELAY:
+  case MEMCACHED_BEHAVIOR_KETAMA:
+  case MEMCACHED_BEHAVIOR_CACHE_LOOKUPS:
+    if (isetting == 1)
+      return_buff.append("1");
+    else if (isetting == 0)
+      return_buff.append("0");
+    else
+    {
+      setFailureString("INVALID VALUE FOR BEHAVIOR - MUST be 1 OR 0!");
+      return &failure_buff;
+    }
+    break;
+  case MEMCACHED_BEHAVIOR_DISTRIBUTION:
+    {
+      string setting(dist_settings_reverse_map[isetting]);
+      return_buff.append(setting.c_str());
+    }
+    break;
+  case MEMCACHED_BEHAVIOR_HASH:
+    {
+      string setting(hash_settings_reverse_map[isetting]);
+      return_buff.append(setting.c_str());
+    }
+    break;
+  case MEMCACHED_BEHAVIOR_KETAMA_HASH:
+    {
+      string setting(ketama_hash_settings_reverse_map[isetting]);
+      return_buff.append(setting.c_str());
+    }
+    break;
+  case MEMCACHED_BEHAVIOR_SOCKET_SEND_SIZE:
+  case MEMCACHED_BEHAVIOR_SOCKET_RECV_SIZE:
+  case MEMCACHED_BEHAVIOR_POLL_TIMEOUT:
+  case MEMCACHED_BEHAVIOR_CONNECT_TIMEOUT:
+  case MEMCACHED_BEHAVIOR_RETRY_TIMEOUT:
+  case MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK:
+  case MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK:
+    {
+      size_t setting_len= 0;
+      char tmp_buff[16];
+
+      snprintf(tmp_buff, 16, "%"PRIu64, isetting);
+      setting_len= strlen(tmp_buff);
+      return_buff.realloc(setting_len);
+      return_buff.length(setting_len);
+      memcpy(return_buff.ptr(),tmp_buff, setting_len);
+    }
+    break;
+  default:
+    break;
+  }
+
+  return &return_buff;
+}

=== added file 'plugin/memcached_functions/memc_behavior_get.h'
--- plugin/memcached_functions/memc_behavior_get.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_behavior_get.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,257 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_BEHAVIOR_GET_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_BEHAVIOR_GET_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/item/func.h>
+
+#include <libmemcached/memcached.h>
+
+#include <map>
+#include <string>
+
+/**
+ * @file
+ *   The memc_behavior_get UDF
+ */
+class MemcachedBehaviorGet : public Item_str_func
+{
+public:
+  MemcachedBehaviorGet()
+    : 
+      Item_str_func(),
+      failure_buff("FAILURE", &my_charset_bin),
+      return_buff("", &my_charset_bin),
+      behavior_map(),
+      behavior_reverse_map(),
+      dist_settings_reverse_map(),
+      hash_settings_reverse_map(),
+      ketama_hash_settings_reverse_map()
+  {
+    /*
+     * std::map for mapping string behaviors to int behavior values
+     * This is used to take user input behaviors from the UDF and 
+     * be able to set the correct int behavior
+     */
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_SUPPORT_CAS", MEMCACHED_BEHAVIOR_SUPPORT_CAS));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_NO_BLOCK", MEMCACHED_BEHAVIOR_NO_BLOCK));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_TCP_NODELAY", MEMCACHED_BEHAVIOR_TCP_NODELAY));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_HASH", MEMCACHED_BEHAVIOR_HASH));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_CACHE_LOOKUPS", MEMCACHED_BEHAVIOR_CACHE_LOOKUPS));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_SOCKET_SEND_SIZE", MEMCACHED_BEHAVIOR_SOCKET_SEND_SIZE));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_SOCKET_RECV_SIZE", MEMCACHED_BEHAVIOR_SOCKET_RECV_SIZE));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_BUFFER_REQUESTS", MEMCACHED_BEHAVIOR_BUFFER_REQUESTS));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_KETAMA", MEMCACHED_BEHAVIOR_KETAMA));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_POLL_TIMEOUT", MEMCACHED_BEHAVIOR_POLL_TIMEOUT));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_RETRY_TIMEOUT", MEMCACHED_BEHAVIOR_RETRY_TIMEOUT));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_DISTRIBUTION", MEMCACHED_BEHAVIOR_DISTRIBUTION));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_USER_DATA", MEMCACHED_BEHAVIOR_USER_DATA));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_SORT_HOSTS", MEMCACHED_BEHAVIOR_SORT_HOSTS));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_VERIFY_KEY", MEMCACHED_BEHAVIOR_VERIFY_KEY));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_CONNECT_TIMEOUT", MEMCACHED_BEHAVIOR_CONNECT_TIMEOUT));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_KETAMA_WEIGHTED", MEMCACHED_BEHAVIOR_KETAMA_WEIGHTED));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_KETAMA_HASH", MEMCACHED_BEHAVIOR_KETAMA_HASH));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_BINARY_PROTOCOL", MEMCACHED_BEHAVIOR_BINARY_PROTOCOL));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_SND_TIMEOUT", MEMCACHED_BEHAVIOR_SND_TIMEOUT));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_RCV_TIMEOUT", MEMCACHED_BEHAVIOR_RCV_TIMEOUT));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_SERVER_FAILURE_LIMIT", MEMCACHED_BEHAVIOR_SERVER_FAILURE_LIMIT));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK", MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK", MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK));
+
+    /*
+     * std::map for mapping int behavior values to behavior strings
+     * This is used to take int behaviors from the the clien and be
+     * able to print the string value of the behavior in memc_behavior_get 
+     * UDF 
+     */
+    behavior_reverse_map.insert(std::pair<memcached_behavior, const std::string>
+      (MEMCACHED_BEHAVIOR_SUPPORT_CAS, "MEMCACHED_BEHAVIOR_SUPPORT_CAS"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_NO_BLOCK, "MEMCACHED_BEHAVIOR_NO_BLOCK"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_TCP_NODELAY, "MEMCACHED_BEHAVIOR_TCP_NODELAY"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_HASH, "MEMCACHED_BEHAVIOR_HASH"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_CACHE_LOOKUPS, "MEMCACHED_BEHAVIOR_CACHE_LOOKUPS"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_SOCKET_SEND_SIZE, "MEMCACHED_BEHAVIOR_SOCKET_SEND_SIZE"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_SOCKET_RECV_SIZE, "MEMCACHED_BEHAVIOR_SOCKET_RECV_SIZE"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_BUFFER_REQUESTS, "MEMCACHED_BEHAVIOR_BUFFER_REQUESTS"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_KETAMA, "MEMCACHED_BEHAVIOR_KETAMA"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_POLL_TIMEOUT, "MEMCACHED_BEHAVIOR_POLL_TIMEOUT"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_RETRY_TIMEOUT, "MEMCACHED_BEHAVIOR_RETRY_TIMEOUT"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_DISTRIBUTION, "MEMCACHED_BEHAVIOR_DISTRIBUTION"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_USER_DATA, "MEMCACHED_BEHAVIOR_USER_DATA"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_SORT_HOSTS, "MEMCACHED_BEHAVIOR_SORT_HOSTS"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_VERIFY_KEY, "MEMCACHED_BEHAVIOR_VERIFY_KEY"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_CONNECT_TIMEOUT, "MEMCACHED_BEHAVIOR_CONNECT_TIMEOUT"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_KETAMA_WEIGHTED, "MEMCACHED_BEHAVIOR_KETAMA_WEIGHTED"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_KETAMA_HASH, "MEMCACHED_BEHAVIOR_KETAMA_HASH"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_BINARY_PROTOCOL, "MEMCACHED_BEHAVIOR_BINARY_PROTOCOL"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_SND_TIMEOUT, "MEMCACHED_BEHAVIOR_SND_TIMEOUT"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_RCV_TIMEOUT, "MEMCACHED_BEHAVIOR_RCV_TIMEOUT"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_SERVER_FAILURE_LIMIT, "MEMCACHED_BEHAVIOR_SERVER_FAILURE_LIMIT"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK, "MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK"));
+    behavior_reverse_map.insert(std::pair<memcached_behavior,const std::string>
+      (MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK, "MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK"));
+
+    /*
+     * std::map for mapping distribution string values to int distribution values
+     * For being able to map int distribution values to string distribution values
+     * Used by memc_behavior_get() for distribution types
+     */
+    dist_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_DISTRIBUTION_MODULA, "MEMCACHED_DISTRIBUTION_MODULA"));
+    dist_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_DISTRIBUTION_CONSISTENT, "MEMCACHED_DISTRIBUTION_CONSISTENT"));
+    dist_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_DISTRIBUTION_CONSISTENT_KETAMA, "MEMCACHED_DISTRIBUTION_CONSISTENT_KETAMA"));
+
+    /*
+     * std::map for mapping distribution string values to int distribution values
+     * For being able to map int distribution values to string distribution values
+     * Used by memc_behavior_get() for hash types
+     */
+    hash_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_HASH_DEFAULT, "MEMCACHED_HASH_DEFAULT"));
+    hash_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_HASH_MD5, "MEMCACHED_HASH_MD5"));
+    hash_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_HASH_CRC, "MEMCACHED_HASH_CRC"));
+    hash_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_HASH_FNV1_64, "MEMCACHED_HASH_FNV1_64"));
+    hash_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_HASH_FNV1A_64, "MEMCACHED_HASH_FNV1A_64"));
+    hash_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_HASH_FNV1_32, "MEMCACHED_HASH_FNV1_32"));
+    hash_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_HASH_FNV1A_32, "MEMCACHED_HASH_FNV1A_32"));
+    hash_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_HASH_JENKINS, "MEMCACHED_HASH_JENKINS"));
+    hash_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_HASH_HSIEH, "MEMCACHED_HASH_HSIEH"));
+    hash_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_HASH_MURMUR, "MEMCACHED_HASH_MURMUR"));
+
+    /*
+     * std::map for mapping distribution string values to int distribution values
+     * For being able to map int distribution values to string distribution values
+     * Used by memc_behavior_get() for ketama hash types
+     */
+    ketama_hash_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_HASH_DEFAULT, "MEMCACHED_HASH_DEFAULT"));
+    ketama_hash_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_HASH_MD5, "MEMCACHED_HASH_MD5"));
+    ketama_hash_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_HASH_CRC, "MEMCACHED_HASH_CRC"));
+    ketama_hash_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_HASH_FNV1_64, "MEMCACHED_HASH_FNV1_64"));
+    ketama_hash_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_HASH_FNV1A_64, "MEMCACHED_HASH_FNV1A_64"));
+    ketama_hash_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_HASH_FNV1_32, "MEMCACHED_HASH_FNV1_32"));
+    ketama_hash_settings_reverse_map.insert(std::pair<uint64_t, const std::string>
+      (MEMCACHED_HASH_FNV1A_32, "MEMCACHED_HASH_FNV1A_32"));
+  }
+
+  const char *func_name() const
+  {
+    return "memc_behavior_set";
+  }
+
+  String *val_str(String *);
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+
+private:
+  void setFailureString(const char *error);
+
+  String failure_buff;
+  String return_buff;
+
+  /*
+   * std::map for behavioral get/set UDFs
+   */
+  std::map<const std::string, memcached_behavior> behavior_map;
+  std::map<memcached_behavior, const std::string> behavior_reverse_map;
+  std::map<uint64_t, const std::string> dist_settings_reverse_map;
+  std::map<uint64_t, const std::string> hash_settings_reverse_map;
+  std::map<uint64_t, const std::string> ketama_hash_settings_reverse_map;
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_BEHAVIOR_GET_H */

=== added file 'plugin/memcached_functions/memc_behavior_set.cc'
--- plugin/memcached_functions/memc_behavior_set.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_behavior_set.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,170 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/item/func.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_behavior_set.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+#include <algorithm>
+
+using namespace std;
+
+void MemcachedBehaviorSet::setFailureString(const char *error)
+{
+  size_t size= strlen(error);
+  failure_buff.realloc(size);
+  failure_buff.length(size);
+  memcpy(failure_buff.ptr(), error, size);
+}
+
+String *MemcachedBehaviorSet::val_str(String *str)
+{
+  memcached_return rc;
+  memcached_behavior mbehavior;
+  uint64_t isetting= 0;
+  map<const string, memcached_behavior>::iterator it_behav;
+  map<const string, uint64_t>::iterator it_hash;
+  map<const string, uint64_t>::iterator it_dist;
+  String *tmp_behavior;
+  String *tmp_setting;
+
+  if (arg_count != 2 ||
+      ! (tmp_behavior= args[0]->val_str(str)) ||
+      ! (tmp_setting= args[1]->val_str(str)) ||
+      ! memc)
+  {
+    setFailureString("USAGE: memc_behavior_set('<behavior type>','<value>')");
+    return &failure_buff;
+  }
+
+  string behavior(tmp_behavior->c_ptr());
+  string setting(tmp_setting->c_ptr());
+
+  /*
+   * We don't want the user to have to type in all input in upper
+   * case so we transform the input strings to upper case here.
+   */
+  std::transform(behavior.begin(), behavior.end(),
+                 behavior.begin(), ::toupper);
+  std::transform(setting.begin(), setting.end(),
+                 setting.begin(), ::toupper);
+
+  it_behav= behavior_map.find(behavior);
+  if (it_behav == behavior_map.end())
+  {
+    setFailureString("UNKNOWN BEHAVIOR TYPE!");
+    return &failure_buff;
+  }
+  mbehavior= behavior_map[behavior];
+
+  switch (mbehavior)
+  {
+  case MEMCACHED_BEHAVIOR_SUPPORT_CAS:
+  case MEMCACHED_BEHAVIOR_NO_BLOCK:
+  case MEMCACHED_BEHAVIOR_BUFFER_REQUESTS:
+  case MEMCACHED_BEHAVIOR_USER_DATA:
+  case MEMCACHED_BEHAVIOR_SORT_HOSTS:
+  case MEMCACHED_BEHAVIOR_VERIFY_KEY:
+  case MEMCACHED_BEHAVIOR_TCP_NODELAY:
+  case MEMCACHED_BEHAVIOR_KETAMA:
+  case MEMCACHED_BEHAVIOR_CACHE_LOOKUPS:
+    if (setting.compare("1") == 0)
+    {
+      isetting= 1;
+    }
+    else if (setting.compare("0") == 0)
+    {
+      isetting= 0;
+    }
+    else
+    {
+      setFailureString("INVALID VALUE FOR BEHAVIOR - MUST be 1 OR 0!");
+      return &failure_buff;
+    }
+    break;
+  case MEMCACHED_BEHAVIOR_DISTRIBUTION:
+    it_dist= dist_settings_map.find(setting);
+    if (it_dist == dist_settings_map.end())
+    {
+      setFailureString("INVALID VALUE FOR DISTRIBUTION!");
+      return &failure_buff;
+    }
+    isetting= dist_settings_map[setting];
+    break;
+  case MEMCACHED_BEHAVIOR_HASH:
+    it_hash= hash_settings_map.find(setting);
+    if (it_hash == hash_settings_map.end())
+    {
+      setFailureString("INVALID VALUE FOR MEMCACHED HASH ALGORITHM!");
+      return &failure_buff;
+    }
+    isetting= hash_settings_map[setting];
+    break;
+  case MEMCACHED_BEHAVIOR_KETAMA_HASH:
+    isetting= ketama_hash_settings_map[setting];
+    if (! isetting)
+    {
+      setFailureString("INVALID VALUE FOR KETAMA HASH ALGORITHM!");
+      return &failure_buff;
+    }
+    break;
+  case MEMCACHED_BEHAVIOR_SOCKET_SEND_SIZE:
+  case MEMCACHED_BEHAVIOR_SOCKET_RECV_SIZE:
+  case MEMCACHED_BEHAVIOR_POLL_TIMEOUT:
+  case MEMCACHED_BEHAVIOR_CONNECT_TIMEOUT:
+  case MEMCACHED_BEHAVIOR_RETRY_TIMEOUT:
+  case MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK:
+  case MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK:
+    /*
+      What type of check the values passed to these behaviors?
+      Range?
+    */
+    break;
+  default:
+    break;
+  }
+
+  rc= memcached_behavior_set(memc, mbehavior, isetting);
+
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    return &failure_buff;
+  }
+
+  return &success_buff;
+}
+

=== added file 'plugin/memcached_functions/memc_behavior_set.h'
--- plugin/memcached_functions/memc_behavior_set.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_behavior_set.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,174 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_BEHAVIOR_SET_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_BEHAVIOR_SET_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/item/func.h>
+
+#include <libmemcached/memcached.h>
+
+#include <map>
+#include <string>
+
+/* implements memc_behavior_set */
+class MemcachedBehaviorSet : public Item_str_func
+{
+public:
+  MemcachedBehaviorSet()
+    : 
+      Item_str_func(),
+      failure_buff("0", &my_charset_bin),
+      success_buff("1", &my_charset_bin),
+      behavior_map(),
+      dist_settings_map(),
+      hash_settings_map(),
+      ketama_hash_settings_map()
+  {
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_SUPPORT_CAS", MEMCACHED_BEHAVIOR_SUPPORT_CAS));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_NO_BLOCK", MEMCACHED_BEHAVIOR_NO_BLOCK));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_TCP_NODELAY", MEMCACHED_BEHAVIOR_TCP_NODELAY));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_HASH", MEMCACHED_BEHAVIOR_HASH));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_CACHE_LOOKUPS", MEMCACHED_BEHAVIOR_CACHE_LOOKUPS));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_SOCKET_SEND_SIZE", MEMCACHED_BEHAVIOR_SOCKET_SEND_SIZE));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_SOCKET_RECV_SIZE", MEMCACHED_BEHAVIOR_SOCKET_RECV_SIZE));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_BUFFER_REQUESTS", MEMCACHED_BEHAVIOR_BUFFER_REQUESTS));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_KETAMA", MEMCACHED_BEHAVIOR_KETAMA));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_POLL_TIMEOUT", MEMCACHED_BEHAVIOR_POLL_TIMEOUT));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_RETRY_TIMEOUT", MEMCACHED_BEHAVIOR_RETRY_TIMEOUT));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_DISTRIBUTION", MEMCACHED_BEHAVIOR_DISTRIBUTION));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_USER_DATA", MEMCACHED_BEHAVIOR_USER_DATA));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_SORT_HOSTS", MEMCACHED_BEHAVIOR_SORT_HOSTS));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_VERIFY_KEY", MEMCACHED_BEHAVIOR_VERIFY_KEY));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_CONNECT_TIMEOUT", MEMCACHED_BEHAVIOR_CONNECT_TIMEOUT));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_KETAMA_WEIGHTED", MEMCACHED_BEHAVIOR_KETAMA_WEIGHTED));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_KETAMA_HASH", MEMCACHED_BEHAVIOR_KETAMA_HASH));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_BINARY_PROTOCOL", MEMCACHED_BEHAVIOR_BINARY_PROTOCOL));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_SND_TIMEOUT", MEMCACHED_BEHAVIOR_SND_TIMEOUT));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_RCV_TIMEOUT", MEMCACHED_BEHAVIOR_RCV_TIMEOUT));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_SERVER_FAILURE_LIMIT", MEMCACHED_BEHAVIOR_SERVER_FAILURE_LIMIT));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK", MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK));
+    behavior_map.insert(std::pair<const std::string, memcached_behavior>
+      ("MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK", MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK));
+
+    dist_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_DISTRIBUTION_MODULA", MEMCACHED_DISTRIBUTION_MODULA));
+    dist_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_DISTRIBUTION_CONSISTENT", MEMCACHED_DISTRIBUTION_CONSISTENT));
+    dist_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_DISTRIBUTION_CONSISTENT_KETAMA", MEMCACHED_DISTRIBUTION_CONSISTENT_KETAMA));
+
+    hash_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_HASH_DEFAULT", MEMCACHED_HASH_DEFAULT));
+    hash_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_HASH_MD5", MEMCACHED_HASH_MD5));
+    hash_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_HASH_CRC", MEMCACHED_HASH_CRC));
+    hash_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_HASH_FNV1_64", MEMCACHED_HASH_FNV1_64));
+    hash_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_HASH_FNV1A_64", MEMCACHED_HASH_FNV1A_64));
+    hash_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_HASH_FNV1_32", MEMCACHED_HASH_FNV1_32));
+    hash_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_HASH_FNV1A_32", MEMCACHED_HASH_FNV1A_32));
+    hash_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_HASH_JENKINS", MEMCACHED_HASH_JENKINS));
+    hash_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_HASH_HSIEH", MEMCACHED_HASH_HSIEH));
+    hash_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_HASH_MURMUR", MEMCACHED_HASH_MURMUR));
+
+    ketama_hash_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_HASH_DEFAULT", MEMCACHED_HASH_DEFAULT));
+    ketama_hash_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_HASH_MD5", MEMCACHED_HASH_MD5));
+    ketama_hash_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_HASH_CRC", MEMCACHED_HASH_CRC));
+    ketama_hash_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_HASH_FNV1_64", MEMCACHED_HASH_FNV1_64));
+    ketama_hash_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_HASH_FNV1A_64", MEMCACHED_HASH_FNV1A_64));
+    ketama_hash_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_HASH_FNV1_32", MEMCACHED_HASH_FNV1_32));
+    ketama_hash_settings_map.insert(std::pair<const std::string, uint64_t>
+      ("MEMCACHED_HASH_FNV1A_32", MEMCACHED_HASH_FNV1A_32));
+  }
+
+  const char *func_name() const
+  {
+    return "memc_behavior_set";
+  }
+
+  String *val_str(String *);
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+
+private:
+  void setFailureString(const char *error);
+
+  String failure_buff;
+  String success_buff;
+
+  std::map<const std::string, memcached_behavior> behavior_map;
+  std::map<const std::string, uint64_t> dist_settings_map;
+  std::map<const std::string, uint64_t> hash_settings_map;
+  std::map<const std::string, uint64_t> ketama_hash_settings_map;
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_BEHAVIOR_SET_H */

=== added file 'plugin/memcached_functions/memc_cas.cc'
--- plugin/memcached_functions/memc_cas.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_cas.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,80 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_cas.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+int64_t MemcachedCas::val_int()
+{
+  memcached_return rc;
+  time_t expiration= 0;
+  String *key;
+  String *res;
+  String *cas;
+  null_value= false;
+
+  if ((arg_count != 3 && arg_count != 4) ||
+      ! (key=   args[0]->val_str(&value)) ||
+      ! (res= args[1]->val_str(&value)) ||
+      ! (cas=   args[2]->val_str(&value)) ||
+      ! memc)
+  {
+    return 0;
+  }
+
+  if (arg_count == 4)
+  {
+    String *tmp_exp= args[3]->val_str(&value);;
+
+    expiration= (time_t)atoi(tmp_exp->c_ptr());
+  }
+
+  rc= memcached_cas(memc, key->c_ptr(), key->length(),
+                    res->c_ptr(), res->length(),
+                    expiration, (uint16_t) 0,
+                    (uint64_t) strtol(cas->c_ptr(), (char **)NULL, 10));
+
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    return 0;
+  }
+
+  return 1;
+}

=== added file 'plugin/memcached_functions/memc_cas.h'
--- plugin/memcached_functions/memc_cas.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_cas.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,69 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_CAS_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_CAS_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/item/func.h>
+#include <string>
+
+/* implements memc_cas */
+class MemcachedCas : public Item_int_func
+{
+  String value;
+  String failure_buff;
+public:
+  MemcachedCas()
+    :
+      Item_int_func(),
+      failure_buff("error ... ", &my_charset_bin)
+  {}
+
+  const char *func_name() const
+  {
+    return "memc_cas";
+  }
+
+  int64_t val_int();
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+  bool check_argument_count(int n)
+  {
+    return ((n == 3 || n == 4));
+  }
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_CAS_H */

=== added file 'plugin/memcached_functions/memc_cas_by_key.cc'
--- plugin/memcached_functions/memc_cas_by_key.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_cas_by_key.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,84 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_cas_by_key.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+int64_t MemcachedCasByKey::val_int()
+{
+  memcached_return rc;
+  time_t expiration= 0;
+  String *master_key;
+  String *key;
+  String *res;
+  String *cas;
+  null_value= false;
+
+  if ((arg_count != 4 && arg_count != 5) ||
+      ! (master_key=   args[0]->val_str(&value)) ||
+      ! (key=   args[1]->val_str(&value)) ||
+      ! (res=   args[2]->val_str(&value)) ||
+      ! (cas=   args[3]->val_str(&value)) ||
+      ! memc)
+  {
+    return 0;
+  }
+
+  if (arg_count == 5)
+  {
+    String *tmp_exp= args[4]->val_str(&value);
+    expiration= (time_t)atoi(tmp_exp->c_ptr());
+  }
+
+  rc= memcached_cas_by_key(memc,
+                    master_key->c_ptr(),
+                    master_key->length(),
+                    key->c_ptr(), key->length(),
+                    res->c_ptr(), res->length(),
+                    expiration, (uint16_t) 0,
+                    (uint64_t) strtol(cas->c_ptr(), (char **)NULL, 10));
+
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    return 0;
+  }
+
+  return 1;
+}

=== added file 'plugin/memcached_functions/memc_cas_by_key.h'
--- plugin/memcached_functions/memc_cas_by_key.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_cas_by_key.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,69 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_CAS_BY_KEY_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_CAS_BY_KEY_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/item/func.h>
+#include <string>
+
+/* implements memc_cas */
+class MemcachedCasByKey : public Item_int_func
+{
+  String failure_buff;
+  String value;
+public:
+  MemcachedCasByKey()
+    :
+      Item_int_func(),
+      failure_buff("failure", &my_charset_bin)
+  {}
+
+  const char *func_name() const
+  {
+    return "memc_cas_by_key";
+  }
+
+  int64_t val_int();
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+  bool check_argument_count(int n)
+  {
+    return ((n == 4 || n == 5));
+  }
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_CAS_BY_KEY_H */

=== added file 'plugin/memcached_functions/memc_decrement.cc'
--- plugin/memcached_functions/memc_decrement.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_decrement.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,91 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_decrement.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+String *MemcachedDecrement::val_str(String *str)
+{
+  memcached_return rc;
+  int64_t offset;
+  uint64_t value;
+  size_t val_len;
+  char tmp_buff[32]= "";
+  String *key;
+  String *dec_str;
+  null_value= false;
+
+  if ((arg_count != 1 && arg_count != 2) ||
+      ! (key= args[0]->val_str(str)) ||
+      ! memc)
+  {
+    return &failure_buff;
+  }
+
+  if (arg_count == 2) {
+    dec_str= args[1]->val_str(str);
+    offset= atoi(dec_str->c_ptr());
+  }
+  else
+  {
+    offset= 1;
+  }
+
+  rc= memcached_decrement(memc,
+                    key->c_ptr(),
+                    key->length(),
+                    offset,
+                    &value);
+
+  snprintf(tmp_buff, 32, "%"PRIu64, value);
+  val_len= strlen(tmp_buff);
+
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    return &failure_buff;
+  }
+
+  buffer.realloc(val_len);
+  buffer.length(val_len);
+  memcpy(buffer.ptr(), tmp_buff, val_len);
+
+  return &buffer;
+}
+

=== added file 'plugin/memcached_functions/memc_decrement.h'
--- plugin/memcached_functions/memc_decrement.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_decrement.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,66 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_DECREMENT_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_DECREMENT_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+/* implements memc_decrement */
+class MemcachedDecrement : public Item_str_func
+{
+public:
+  MemcachedDecrement()
+    : 
+      Item_str_func(),
+      failure_buff("FAILURE", &my_charset_bin)
+  {}
+
+  const char *func_name() const
+  {
+    return "memc_decrement";
+  }
+
+  String *val_str(String *);
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+
+private:
+  String failure_buff;
+  String buffer;
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_DECREMENT_H */

=== added file 'plugin/memcached_functions/memc_delete.cc'
--- plugin/memcached_functions/memc_delete.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_delete.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,65 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_delete.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+
+int64_t MemcachedDelete::val_int()
+{
+  memcached_return rc;
+  String *key;
+  null_value= false;
+
+  if (arg_count != 1 ||
+      ! (key= args[0]->val_str(&value)) ||
+      ! memc)
+  {
+    return 0;
+  }
+
+  rc= memcached_delete(memc, key->c_ptr(), key->length(), 0);
+
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    return 0;
+  }
+
+  return 1;
+}

=== added file 'plugin/memcached_functions/memc_delete.h'
--- plugin/memcached_functions/memc_delete.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_delete.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,70 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_DELETE_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_DELETE_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/item/func.h>
+#include <string>
+
+/* implements memc_delete */
+class MemcachedDelete : public Item_int_func
+{
+  String failure_buff;
+  String value;
+public:
+  MemcachedDelete()
+    :
+      Item_int_func(),
+      failure_buff("0", &my_charset_bin)
+  {}
+
+  const char *func_name() const
+  {
+    return "memc_delete";
+  }
+
+  int64_t val_int();
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+  bool check_argument_count(int n)
+  {
+    return (n == 1);
+  }
+
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_DELETE_H */

=== added file 'plugin/memcached_functions/memc_delete_by_key.cc'
--- plugin/memcached_functions/memc_delete_by_key.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_delete_by_key.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,70 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_delete_by_key.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+int64_t MemcachedDeleteByKey::val_int()
+{
+  memcached_return rc;
+  String *master_key;
+  String *key;
+  null_value= false;
+
+  if (arg_count != 2 ||
+      ! (master_key=  args[0]->val_str(&value)) ||
+      ! (key=         args[0]->val_str(&value)) ||
+      ! memc)
+  {
+    return 0;
+  }
+
+  rc= memcached_delete_by_key(memc,
+                       master_key->c_ptr(),
+                       master_key->length(),
+                       key->c_ptr(), key->length(), 0);
+
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    return 0;
+  }
+
+  return 1;
+}

=== added file 'plugin/memcached_functions/memc_delete_by_key.h'
--- plugin/memcached_functions/memc_delete_by_key.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_delete_by_key.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,73 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_DELETE_BY_KEY_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_DELETE_BY_KEY_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/item/func.h>
+#include <string>
+
+using namespace std;
+using namespace drizzled;
+
+/* implements memc_delete */
+class MemcachedDeleteByKey : public Item_int_func
+{
+  String failure_buff;
+  String value;
+public:
+  MemcachedDeleteByKey()
+    :
+      Item_int_func(),
+      failure_buff("0", &my_charset_bin)
+  {}
+
+  const char *func_name() const
+  {
+    return "memc_delete_by_key";
+  }
+
+  int64_t val_int();
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+  bool check_argument_count(int n)
+  {
+    return (n == 2);
+  }
+
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_DELETE_BY_KEY_H */

=== added file 'plugin/memcached_functions/memc_get.cc'
--- plugin/memcached_functions/memc_get.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_get.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,80 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+/**
+ * @file
+ *   memc_get UDF implementation 
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_get.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+/**
+ * value function for memc_get UDF
+ *
+ * @return string value from memcached 
+ */
+String *MemcachedGet::val_str(String *str)
+{
+  memcached_return rc;
+  String *key;
+  uint32_t flags;
+  size_t val_len;
+
+  if (arg_count != 1 ||
+      ! (key= args[0]->val_str(str)) ||
+      ! memc)
+  {
+    return &failure_buff;
+  }
+
+  char *value= memcached_get(memc, key->c_ptr(), key->length(), &val_len, &flags, &rc);
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    null_value= true;
+    return NULL;
+  }
+
+  buffer.realloc(val_len);
+  buffer.length(val_len);
+  memcpy(buffer.ptr(), value, val_len);
+
+  return &buffer;
+}
+

=== added file 'plugin/memcached_functions/memc_get.h'
--- plugin/memcached_functions/memc_get.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_get.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,65 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_GET_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_GET_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+/* implements memc_get */
+class MemcachedGet : public Item_str_func
+{
+public:
+  MemcachedGet()
+    : 
+      Item_str_func(),
+      failure_buff("FAILURE", &my_charset_bin)
+  {}
+
+  const char *func_name() const
+  {
+    return "memc_get";
+  }
+
+  String *val_str(String *);
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+
+private:
+  String failure_buff;
+  String buffer;
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_GET_H */

=== added file 'plugin/memcached_functions/memc_get_by_key.cc'
--- plugin/memcached_functions/memc_get_by_key.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_get_by_key.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,77 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_get_by_key.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+String *MemcachedGetByKey::val_str(String *str)
+{
+  memcached_return rc;
+  String *master_key;
+  String *key;
+  uint32_t flags;
+  size_t val_len;
+
+  if (arg_count != 2 ||
+      ! (master_key= args[0]->val_str(str)) ||
+      ! (key= args[1]->val_str(str)) ||
+      ! memc)
+  {
+    return &failure_buff;
+  }
+
+  char *value= memcached_get_by_key(memc,
+                                    master_key->c_ptr(),
+                                    master_key->length(),
+                                    key->c_ptr(), key->length(),
+                                    &val_len, &flags, &rc);
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    null_value= true;
+    return NULL;
+  }
+
+  buffer.realloc(val_len);
+  buffer.length(val_len);
+  memcpy(buffer.ptr(), value, val_len);
+
+  return &buffer;
+}
+

=== added file 'plugin/memcached_functions/memc_get_by_key.h'
--- plugin/memcached_functions/memc_get_by_key.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_get_by_key.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,66 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_GET_BY_KEY_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_GET_BY_KEY_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+/* implements memc_get_by_key */
+class MemcachedGetByKey : public Item_str_func
+{
+public:
+  MemcachedGetByKey()
+    : 
+      Item_str_func(),
+      failure_buff("FAILURE", &my_charset_bin)
+  {}
+
+  const char *func_name() const
+  {
+    return "memc_get_by_key";
+  }
+
+  String *val_str(String *);
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+
+private:
+  String failure_buff;
+  String buffer;
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_GET_BY_KEY_H */

=== added file 'plugin/memcached_functions/memc_increment.cc'
--- plugin/memcached_functions/memc_increment.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_increment.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,92 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_increment.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+String *MemcachedIncrement::val_str(String *str)
+{
+  memcached_return rc;
+  int64_t offset;
+  uint64_t value;
+  size_t val_len;
+  char tmp_buff[32]= "";
+  String *key;
+  String *inc_str;
+
+  if ((arg_count != 1 && arg_count != 2) ||
+      ! (key= args[0]->val_str(str)) ||
+      ! memc)
+  {
+    return &failure_buff;
+  }
+
+  if (arg_count == 2) {
+    inc_str= args[1]->val_str(str);
+    offset= atoi(inc_str->c_ptr());
+  }
+  else
+  {
+    offset= 1;
+  }
+
+
+  rc= memcached_increment(memc,
+                    key->c_ptr(),
+                    key->length(),
+                    offset,
+                    &value);
+
+  snprintf(tmp_buff, 32, "%"PRIu64, value);
+  val_len= strlen(tmp_buff);
+
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    return &failure_buff;
+  }
+
+  buffer.realloc(val_len);
+  buffer.length(val_len);
+  memcpy(buffer.ptr(), tmp_buff, val_len);
+
+  return &buffer;
+}
+

=== added file 'plugin/memcached_functions/memc_increment.h'
--- plugin/memcached_functions/memc_increment.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_increment.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,65 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_INCREMENT_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_INCREMENT_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+/* implements memc_increment */
+class MemcachedIncrement : public Item_str_func
+{
+public:
+  MemcachedIncrement()
+    : 
+      Item_str_func(),
+      failure_buff("FAILURE", &my_charset_bin)
+  {}
+
+  const char *func_name() const
+  {
+    return "memc_increment";
+  }
+
+  String *val_str(String *);
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+
+private:
+  String failure_buff;
+  String buffer;
+};
+
+#endif /* MEMC_INCREMENT_H */

=== added file 'plugin/memcached_functions/memc_misc.cc'
--- plugin/memcached_functions/memc_misc.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_misc.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,70 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_misc.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+String *MemcachedVersion::val_str(String*)
+{
+  if (! memc)
+  {
+    return &failure_buff;
+  }
+
+  const char *version= memcached_lib_version();
+  size_t ver_len= strlen(version);
+
+  buffer.realloc(ver_len);
+  buffer.length(ver_len);
+  memcpy(buffer.ptr(), version, ver_len);
+
+  return &buffer;
+}
+
+int64_t MemcachedServerCount::val_int()
+{
+  if (! memc)
+  {
+    return 0;
+  }
+
+  return (memcached_server_count(memc));
+}

=== added file 'plugin/memcached_functions/memc_misc.h'
--- plugin/memcached_functions/memc_misc.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_misc.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,90 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_MISC_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_MISC_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/item/func.h>
+#include <drizzled/function/str/strfunc.h>
+
+/* implements memc_libmemcached_version */
+class MemcachedVersion : public Item_str_func
+{
+public:
+  MemcachedVersion()
+    : 
+      Item_str_func(),
+      failure_buff("FAILURE", &my_charset_bin)
+  {}
+
+  const char *func_name() const
+  {
+    return "memc_libmemcached_version";
+  }
+
+  String *val_str(String *);
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+
+private:
+  String buffer;
+  String failure_buff;
+};
+
+/* implements memc_server_count */
+class MemcachedServerCount : public Item_int_func
+{
+public:
+  MemcachedServerCount()
+    :
+      Item_int_func()
+  {
+    unsigned_flag= 1;
+  }
+
+  const char *func_name() const
+  {
+    return "memc_server_count";
+  }
+
+  void fix_length_and_dec()
+  {
+    max_length= 10;
+  }
+
+  int64_t val_int();
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_MISC_H */

=== added file 'plugin/memcached_functions/memc_prepend.cc'
--- plugin/memcached_functions/memc_prepend.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_prepend.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,74 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_prepend.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+int64_t MemcachedPrepend::val_int()
+{
+  memcached_return rc;
+  time_t expiration= 0;
+  String *key;
+  String *res;
+  null_value= false;
+
+  if ((arg_count != 2 && arg_count != 3) ||
+      ! (key= args[0]->val_str(&value)) ||
+      ! (res= args[1]->val_str(&value)) ||
+      ! memc)
+  {
+    return 0;
+  }
+  if (arg_count == 3)
+  {
+    String *tmp_exp= args[2]->val_str(&value);
+    expiration= (time_t)atoi(tmp_exp->c_ptr());
+  }
+
+  rc= memcached_prepend(memc, key->c_ptr(), key->length(),
+                       res->c_ptr(), res->length(),
+                       expiration, (uint16_t) 0);
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    return 0;
+  }
+  return 1;
+}

=== added file 'plugin/memcached_functions/memc_prepend.h'
--- plugin/memcached_functions/memc_prepend.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_prepend.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,71 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_PREPEND_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_PREPEND_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/item/func.h>
+#include <string>
+
+/* implements memc_prepend */
+class MemcachedPrepend : public Item_int_func
+{
+  String failure_buff;
+  String value;
+public:
+  MemcachedPrepend()
+    :
+      Item_int_func(),
+      failure_buff("0", &my_charset_bin)
+  {}
+
+  const char *func_name() const
+  {
+    return "memc_prepend";
+  }
+
+  int64_t val_int();
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+  bool check_argument_count(int n)
+  {
+    return ((n == 2 || n == 3));
+  }
+
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_PREPEND_H */

=== added file 'plugin/memcached_functions/memc_prepend_by_key.cc'
--- plugin/memcached_functions/memc_prepend_by_key.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_prepend_by_key.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,80 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_prepend_by_key.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+int64_t MemcachedPrependByKey::val_int()
+{
+  memcached_return rc;
+  time_t expiration= 0;
+  String *master_key;
+  String *key;
+  String *res;
+  null_value= false;
+
+  if ((arg_count != 3 && arg_count != 4) ||
+      ! (master_key=  args[0]->val_str(&value)) ||
+      ! (key=         args[1]->val_str(&value)) ||
+      ! (res=         args[2]->val_str(&value)) ||
+      ! memc)
+  {
+    return 0;
+  }
+  if (arg_count == 4)
+  {
+    String *tmp_exp= args[3]->val_str(&value);;
+    expiration= (time_t)atoi(tmp_exp->c_ptr());
+  }
+
+  rc= memcached_prepend_by_key(memc,
+                              master_key->c_ptr(),
+                              master_key->length(),
+                              key->c_ptr(), key->length(),
+                              res->c_ptr(), res->length(),
+                              expiration, (uint16_t) 0);
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    return 0;
+  }
+
+  return 1;
+}

=== added file 'plugin/memcached_functions/memc_prepend_by_key.h'
--- plugin/memcached_functions/memc_prepend_by_key.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_prepend_by_key.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,73 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_PREPEND_BY_KEY_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_PREPEND_BY_KEY_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/item/func.h>
+#include <string>
+
+
+/* implements memc_prepend_by_key */
+class MemcachedPrependByKey : public Item_int_func
+{
+  String failure_buff;
+  String value;
+public:
+  MemcachedPrependByKey()
+    :
+      Item_int_func(),
+      failure_buff("failure ...", &my_charset_bin)
+  {}
+
+  const char *func_name() const
+  {
+    return "memc_prepend_by_key";
+  }
+
+  int64_t val_int();
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+  bool check_argument_count(int n)
+  {
+    return ((n == 3 || n == 4));
+  }
+
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_PREPEND_BY_KEY_H */

=== added file 'plugin/memcached_functions/memc_replace.cc'
--- plugin/memcached_functions/memc_replace.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_replace.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,78 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_replace.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+int64_t MemcachedReplace::val_int()
+{
+  memcached_return rc;
+  time_t expiration= 0;
+  String *key;
+  String *res;
+  null_value= false;
+
+  if ((arg_count != 2 && arg_count != 3) ||
+      ! (key= args[0]->val_str(&value)) ||
+      ! (res= args[1]->val_str(&value)) ||
+      ! memc)
+  {
+    return 0;
+  }
+
+  if (arg_count == 3)
+  {
+    String *tmp_exp= args[2]->val_str(&value);;
+
+    expiration= (time_t)atoi(tmp_exp->c_ptr());
+  }
+
+  rc= memcached_replace(memc, key->c_ptr(), key->length(),
+                    res->c_ptr(), res->length(),
+                    expiration, (uint16_t) 0);
+
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    return 0;
+  }
+
+  return 1;
+}

=== added file 'plugin/memcached_functions/memc_replace.h'
--- plugin/memcached_functions/memc_replace.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_replace.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,71 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_REPLACE_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_REPLACE_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/item/func.h>
+#include <string>
+
+/* implements memc_replace */
+class MemcachedReplace: public Item_int_func
+{
+  String failure_buff;
+  String value;
+public:
+  MemcachedReplace()
+    :
+      Item_int_func(),
+      failure_buff("0", &my_charset_bin)
+  {}
+
+  const char *func_name() const
+  {
+    return "memc_replace";
+  }
+
+  int64_t val_int();
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+  bool check_argument_count(int n)
+  {
+    return ((n == 2 || n == 3));
+  }
+
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_REPLACE_H */

=== added file 'plugin/memcached_functions/memc_replace_by_key.cc'
--- plugin/memcached_functions/memc_replace_by_key.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_replace_by_key.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,82 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_replace_by_key.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+int64_t MemcachedReplaceByKey::val_int()
+{
+  memcached_return rc;
+  time_t expiration= 0;
+  String *master_key;
+  String *key;
+  String *res;
+  null_value= false;
+
+  if ((arg_count != 3 && arg_count != 4) ||
+      ! (master_key= args[0]->val_str(&value)) ||
+      ! (key= args[1]->val_str(&value)) ||
+      ! (res= args[2]->val_str(&value)) ||
+      ! memc)
+  {
+    return 0;
+  }
+
+  if (arg_count == 4)
+  {
+    String *tmp_exp= args[3]->val_str(&value);;
+
+    expiration= (time_t)atoi(tmp_exp->c_ptr());
+  }
+
+  rc= memcached_replace_by_key(memc,
+                           master_key->c_ptr(), master_key->length(),
+                           key->c_ptr(), key->length(),
+                           res->c_ptr(), res->length(),
+                           expiration, (uint16_t) 0);
+
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    return 0;
+  }
+
+  return 1;
+}

=== added file 'plugin/memcached_functions/memc_replace_by_key.h'
--- plugin/memcached_functions/memc_replace_by_key.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_replace_by_key.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,72 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_REPLACE_BY_KEY_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_REPLACE_BY_KEY_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/item/func.h>
+#include <string>
+
+
+/* implements memc_replace_by_key */
+class MemcachedReplaceByKey : public Item_int_func
+{
+  String value;
+  String failure_buff;
+public:
+  MemcachedReplaceByKey()
+    :
+      Item_int_func(),
+     failure_buff("0", &my_charset_bin)
+  {}
+
+  const char *func_name() const
+  {
+    return "memc_replace_by_key";
+  }
+
+  int64_t val_int();
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+  bool check_argument_count(int n)
+  {
+    return ((n == 3 || n == 4));
+  }
+
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_SET_BY_KEY_H */

=== added file 'plugin/memcached_functions/memc_servers_set.cc'
--- plugin/memcached_functions/memc_servers_set.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_servers_set.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,72 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ *
+ */
+
+#include <drizzled/server_includes.h>
+
+#include "memcached_functions.h"
+#include "memc_servers_set.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+int64_t MemcachedServersSet::val_int()
+{
+  memcached_return rc;
+  memcached_server_st *servers;
+  String *server_names;
+  null_value= false;
+
+  if (arg_count != 1 ||
+      ! (server_names= args[0]->val_str(&value)) ||
+      ! memc)
+  {
+    return 0;
+  }
+
+  servers= memcached_servers_parse(server_names->c_ptr());
+  if (servers == NULL)
+  {
+    return 0;
+  }
+
+  rc= memcached_server_push(memc, servers);
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    return 0;
+  }
+
+  return 1;
+}

=== added file 'plugin/memcached_functions/memc_servers_set.h'
--- plugin/memcached_functions/memc_servers_set.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_servers_set.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,77 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ *
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_SERVERS_SET_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_SERVERS_SET_H
+
+#include <string>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/server_includes.h>
+#include <drizzled/item/func.h>
+
+/* implements memc_servers_set */
+class MemcachedServersSet : public Item_int_func
+{
+private:
+  String failure_buff;
+  String value;
+public:
+  MemcachedServersSet()
+    :
+      Item_int_func(),
+      failure_buff("FAILURE", &my_charset_bin)
+  {}
+
+  const char *func_name() const
+  {
+    return "memc_servers_set";
+  }
+
+  int64_t val_int();
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+    args[0]->collation.set(
+      get_charset_by_csname(args[0]->collation.collation->csname,
+                            MY_CS_BINSORT),
+      DERIVATION_COERCIBLE);
+  }
+  bool check_argument_count(int n)
+  {
+    return (n == 1);
+  }
+
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_SERVERS_SET_H */

=== added file 'plugin/memcached_functions/memc_set.cc'
--- plugin/memcached_functions/memc_set.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_set.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,79 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ *
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_set.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+int64_t MemcachedSet::val_int()
+{
+  memcached_return rc;
+  time_t expiration= 0;
+  String *key;
+  String *res;
+  null_value= false;
+
+  if ((arg_count != 2 && arg_count != 3) ||
+      ! (key= args[0]->val_str(&value)) ||
+      ! (res= args[1]->val_str(&value)) ||
+      ! memc)
+  {
+    return 0;
+  }
+
+  if (arg_count == 3)
+  {
+    String *tmp_exp= args[2]->val_str(&value);;
+
+    expiration= (time_t)atoi(tmp_exp->c_ptr());
+  }
+
+  rc= memcached_set(memc, key->c_ptr(), key->length(),
+                    res->c_ptr(), res->length(),
+                    expiration, (uint16_t) 0);
+
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    return 0;
+  }
+
+  return 1;
+}

=== added file 'plugin/memcached_functions/memc_set.h'
--- plugin/memcached_functions/memc_set.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_set.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,65 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_SET_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_SET_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/item/func.h>
+#include <string>
+
+/* implements memc_set */
+class MemcachedSet :public Item_int_func
+{
+  String failure_buff;
+  String value;
+public:
+  int64_t val_int();
+  MemcachedSet() :Item_int_func() {}
+
+  const char *func_name() const
+  {
+    return "memc_set";
+  }
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+  bool check_argument_count(int n)
+  {
+    return ((n == 2 || n == 3));
+  }
+
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_SET_H */

=== added file 'plugin/memcached_functions/memc_set_by_key.cc'
--- plugin/memcached_functions/memc_set_by_key.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_set_by_key.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,81 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_set_by_key.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+
+int64_t MemcachedSetByKey::val_int()
+{
+  memcached_return rc;
+  time_t expiration= 0;
+  String *master_key;
+  String *key;
+  String *res;
+  null_value= false; 
+
+  if ((arg_count != 3 && arg_count != 4) ||
+      ! (master_key= args[0]->val_str(&value)) ||
+      ! (key= args[1]->val_str(&value)) ||
+      ! (res= args[2]->val_str(&value)) ||
+      ! memc)
+  {
+    return 0;
+  }
+
+  if (arg_count == 4)
+  {
+    String *tmp_exp= args[3]->val_str(&value);;
+    expiration= (time_t)atoi(tmp_exp->c_ptr());
+  }
+
+  rc= memcached_set_by_key(memc,
+                           master_key->c_ptr(), master_key->length(),
+                           key->c_ptr(), key->length(),
+                           res->c_ptr(), res->length(),
+                           expiration, (uint16_t) 0);
+
+  if (rc != MEMCACHED_SUCCESS)
+  {
+    return 0;
+  }
+
+  return 1;
+}

=== added file 'plugin/memcached_functions/memc_set_by_key.h'
--- plugin/memcached_functions/memc_set_by_key.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_set_by_key.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,70 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_SET_BY_KEY_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_SET_BY_KEY_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/item/func.h>
+#include <string>
+
+/* implements memc_set_by_key */
+class MemcachedSetByKey : public Item_int_func
+{
+  String value;
+  String failure_buff;
+public:
+  MemcachedSetByKey()
+    :
+      Item_int_func(),
+      failure_buff("error ...", &my_charset_bin)
+  {}
+
+  const char *func_name() const
+  {
+    return "memc_set_by_key";
+  }
+
+  int64_t val_int();
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+  bool check_argument_count(int n)
+  {
+    return ((n == 3 || n == 4));
+  }
+
+};
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_SET_BY_KEY_H */

=== added file 'plugin/memcached_functions/memc_stats.cc'
--- plugin/memcached_functions/memc_stats.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_stats.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,130 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/item/func.h>
+#include <drizzled/function/str/strfunc.h>
+
+#include "memcached_functions.h"
+#include "memc_stats.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+#include <algorithm>
+
+using namespace std;
+
+void MemcachedStats::setFailureString(const char *error)
+{
+  size_t size= strlen(error);
+  failure_buff.realloc(size);
+  failure_buff.length(size);
+  memcpy(failure_buff.ptr(), error, size);
+}
+
+String *MemcachedStats::val_str(String *str)
+{
+  memcached_return rc;
+  unsigned int count;
+  char buff[100];
+  memcached_stat_st *stat;
+  memcached_server_st *servers;
+  memcached_server_st *server_list;
+  String *server_names;
+
+
+  if (arg_count != 1 ||
+      ! (server_names= args[0]->val_str(str)) ||
+      ! memc)
+  {
+    setFailureString("USAGE: memc_stats('<server list>')");
+    return &failure_buff;
+  }
+
+  servers= memcached_servers_parse(server_names->c_ptr());
+  if (servers == NULL)
+  {
+    setFailureString(" ERROR: unable to parse servers string!");
+    return &failure_buff;
+  }
+  memcached_server_push(memc, servers);
+  memcached_server_list_free(servers);
+
+  stat= memcached_stat(memc, NULL, &rc);
+
+  if (rc != MEMCACHED_SUCCESS && rc != MEMCACHED_SOME_ERRORS)
+  {
+    snprintf(buff, 100, "Failure to communicate with servers (%s)\n",
+            memcached_strerror(memc, rc));
+
+    setFailureString(buff);
+    return &failure_buff;
+  }
+
+  server_list= memcached_server_list(memc);
+
+  results_buff.length(0);
+  snprintf(buff, 100, "Listing %u Server\n\n", memcached_server_count(memc));
+  results_buff.append(buff);
+
+  for (count= 0; count < memcached_server_count(memc); count++)
+  {
+    char **list;
+    char **ptr;
+
+    list= memcached_stat_get_keys(memc, &stat[count], &rc);
+
+    snprintf(buff, 100, "Server: %s (%u)\n",
+            memcached_server_name(memc, server_list[count]),
+            memcached_server_port(memc, server_list[count]));
+
+
+    results_buff.append(buff);
+
+    for (ptr= list; *ptr; ptr++)
+    {
+      char *value= memcached_stat_get_value(memc, &stat[count], *ptr, &rc);
+
+      snprintf(buff, 100, "\t %s: %s\n", *ptr, value);
+      free(value);
+      results_buff.append(buff);
+    }
+
+    free(list);
+    results_buff.append("\n");
+  }
+
+  free(stat);
+
+  return &results_buff;
+
+}

=== added file 'plugin/memcached_functions/memc_stats.h'
--- plugin/memcached_functions/memc_stats.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memc_stats.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,74 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_STATS_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMC_STATS_H
+
+#include <drizzled/server_includes.h>
+#include <drizzled/item/func.h>
+
+#include <libmemcached/memcached.h>
+
+#include <map>
+#include <string>
+
+/* implements memc_stats */
+class MemcachedStats: public Item_str_func
+{
+public:
+  MemcachedStats()
+    :
+      Item_str_func(),
+      failure_buff("FAILURE: ", &my_charset_bin),
+      results_buff("", &my_charset_bin)
+  {
+  }
+
+  const char *func_name() const
+  {
+    return "memc_stats";
+  }
+
+  String *val_str(String *);
+
+  void fix_length_and_dec()
+  {
+    max_length= 32;
+  }
+
+private:
+  void setFailureString(const char *error);
+
+  String failure_buff;
+  String results_buff;
+};
+
+#endif /* MEMC_STATS_H */

=== added file 'plugin/memcached_functions/memcached_functions.cc'
--- plugin/memcached_functions/memcached_functions.cc	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memcached_functions.cc	2009-10-08 22:42:05 +0000
@@ -0,0 +1,387 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#include <drizzled/server_includes.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/plugin/function.h>
+
+#include "memcached_functions.h"
+#include "memc_servers_set.h"
+#include "memc_behavior_set.h"
+#include "memc_behavior_get.h"
+#include "memc_stats.h"
+#include "memc_get.h"
+#include "memc_get_by_key.h"
+#include "memc_set.h"
+#include "memc_set_by_key.h"
+#include "memc_add.h"
+#include "memc_add_by_key.h"
+#include "memc_replace.h"
+#include "memc_replace_by_key.h"
+#include "memc_delete.h"
+#include "memc_delete_by_key.h"
+#include "memc_append.h"
+#include "memc_append_by_key.h"
+#include "memc_prepend.h"
+#include "memc_prepend_by_key.h"
+#include "memc_cas.h"
+#include "memc_cas_by_key.h"
+#include "memc_increment.h"
+#include "memc_decrement.h"
+#include "memc_misc.h"
+
+#include <libmemcached/memcached.h>
+
+#include <string>
+
+using namespace std;
+using namespace drizzled;
+
+/*
+ * A global memcached data structure needed by
+ * the various libmemcached API functions.
+ */
+memcached_st *memc= NULL;
+
+/*
+ * The memcached UDF's.
+ */
+plugin::Create_function<MemcachedServersSet> *memc_servers_set= NULL;
+plugin::Create_function<MemcachedBehaviorSet> *memc_behavior_set= NULL;
+plugin::Create_function<MemcachedBehaviorGet> *memc_behavior_get= NULL;
+plugin::Create_function<MemcachedStats> *memc_stats= NULL;
+plugin::Create_function<MemcachedGet> *memc_get= NULL;
+plugin::Create_function<MemcachedGetByKey> *memc_get_by_key= NULL;
+plugin::Create_function<MemcachedSet> *memc_set= NULL;
+plugin::Create_function<MemcachedSetByKey> *memc_set_by_key= NULL;
+plugin::Create_function<MemcachedAdd> *memc_add= NULL;
+plugin::Create_function<MemcachedAddByKey> *memc_add_by_key= NULL;
+plugin::Create_function<MemcachedReplace> *memc_replace= NULL;
+plugin::Create_function<MemcachedReplaceByKey> *memc_replace_by_key= NULL;
+plugin::Create_function<MemcachedIncrement> *memc_increment= NULL;
+plugin::Create_function<MemcachedDecrement> *memc_decrement= NULL;
+plugin::Create_function<MemcachedDelete> *memc_delete= NULL;
+plugin::Create_function<MemcachedDeleteByKey> *memc_delete_by_key= NULL;
+plugin::Create_function<MemcachedAppend> *memc_append= NULL;
+plugin::Create_function<MemcachedAppendByKey> *memc_append_by_key= NULL;
+plugin::Create_function<MemcachedPrepend> *memc_prepend= NULL;
+plugin::Create_function<MemcachedPrependByKey> *memc_prepend_by_key= NULL;
+plugin::Create_function<MemcachedCas> *memc_cas= NULL;
+plugin::Create_function<MemcachedCasByKey> *memc_cas_by_key= NULL;
+plugin::Create_function<MemcachedServerCount> *memc_serv_count= NULL;
+plugin::Create_function<MemcachedVersion> *memc_version= NULL;
+
+bool initMemcUDF()
+{
+  memc_servers_set= new plugin::Create_function<MemcachedServersSet>("memc_servers_set");
+  if (memc_servers_set == NULL)
+  {
+    return true;
+  }
+
+  memc_behavior_set= new plugin::Create_function<MemcachedBehaviorSet>("memc_behavior_set");
+  if (memc_behavior_set == NULL)
+  {
+    return true;
+  }
+
+  memc_behavior_get= new plugin::Create_function<MemcachedBehaviorGet>("memc_behavior_get");
+  if (memc_behavior_get == NULL)
+  {
+    return true;
+  }
+
+  memc_stats= new plugin::Create_function<MemcachedStats>("memc_stats");
+  if (memc_stats == NULL)
+  {
+    return true;
+  }
+
+  memc_get= new plugin::Create_function<MemcachedGet>("memc_get");
+  if (memc_get == NULL)
+  {
+    return true;
+  }
+
+  memc_get_by_key= new plugin::Create_function<MemcachedGetByKey>("memc_get_by_key");
+  if (memc_get_by_key == NULL)
+  {
+    return true;
+  }
+
+  memc_set= new plugin::Create_function<MemcachedSet>("memc_set");
+  if (memc_set == NULL)
+  {
+    return true;
+  }
+  memc_set_by_key= new plugin::Create_function<MemcachedSetByKey>("memc_set_by_key");
+  if (memc_set_by_key == NULL)
+  {
+    return true;
+  }
+
+  memc_add= new plugin::Create_function<MemcachedAdd>("memc_add");
+  if (memc_add== NULL)
+  {
+    return true;
+  }
+
+  memc_add_by_key= new plugin::Create_function<MemcachedAddByKey>("memc_add_by_key");
+  if (memc_add_by_key == NULL)
+  {
+    return true;
+  }
+
+  memc_replace= new plugin::Create_function<MemcachedReplace>("memc_replace");
+  if (memc_replace== NULL)
+  {
+    return true;
+  }
+
+  memc_replace_by_key= new plugin::Create_function<MemcachedReplaceByKey>("memc_replace_by_key");
+  if (memc_replace_by_key == NULL)
+  {
+    return true;
+  }
+
+  memc_delete= new plugin::Create_function<MemcachedDelete>("memc_delete");
+  if (memc_delete == NULL)
+  {
+    return true;
+  }
+
+  memc_delete_by_key= new plugin::Create_function<MemcachedDeleteByKey>("memc_delete_by_key");
+  if (memc_delete_by_key == NULL)
+  {
+    return true;
+  }
+
+  memc_append= new plugin::Create_function<MemcachedAppend>("memc_append");
+  if (memc_append == NULL)
+  {
+    return true;
+  }
+
+  memc_append_by_key= new plugin::Create_function<MemcachedAppendByKey>("memc_append_by_key");
+  if (memc_append_by_key == NULL)
+  {
+    return true;
+  }
+
+  memc_prepend= new plugin::Create_function<MemcachedPrepend>("memc_prepend");
+  if (memc_prepend == NULL)
+  {
+    return true;
+  }
+
+  memc_prepend_by_key= new plugin::Create_function<MemcachedPrependByKey>("memc_prepend_by_key");
+  if (memc_prepend_by_key == NULL)
+  {
+    return true;
+  }
+
+  memc_cas= new plugin::Create_function<MemcachedCas>("memc_cas");
+  if (memc_cas == NULL)
+  {
+    return true;
+  }
+
+  memc_cas_by_key= new plugin::Create_function<MemcachedCasByKey>("memc_cas_by_key");
+  if (memc_cas_by_key == NULL)
+  {
+    return true;
+  }
+
+  memc_serv_count= new plugin::Create_function<MemcachedServerCount>("memc_server_count");
+  if (memc_serv_count == NULL)
+  {
+    return true;
+  }
+
+  memc_version= new plugin::Create_function<MemcachedVersion>("memc_libmemcached_version");
+  if (memc_version == NULL)
+  {
+    return true;
+  }
+
+  memc_increment= new plugin::Create_function<MemcachedIncrement>("memc_increment");
+  if (memc_increment == NULL)
+  {
+    return true;
+  }
+
+  memc_decrement= new plugin::Create_function<MemcachedDecrement>("memc_decrement");
+  if (memc_decrement == NULL)
+  {
+    return true;
+  }
+
+  return false;
+}
+
+void cleanupMemcUDF()
+{
+  delete memc_servers_set;
+  delete memc_behavior_set;
+  delete memc_behavior_get;
+  delete memc_stats;
+  delete memc_get;
+  delete memc_get_by_key;
+  delete memc_set;
+  delete memc_set_by_key;
+  delete memc_add;
+  delete memc_add_by_key;
+  delete memc_replace;
+  delete memc_replace_by_key;
+  delete memc_delete;
+  delete memc_delete_by_key;
+  delete memc_append;
+  delete memc_append_by_key;
+  delete memc_prepend;
+  delete memc_prepend_by_key;
+  delete memc_cas;
+  delete memc_cas_by_key;
+  delete memc_serv_count;
+  delete memc_version;
+  delete memc_increment;
+  delete memc_decrement;
+}
+
+static int memcachedInit(drizzled::plugin::Registry &registry)
+{
+  if (initMemcUDF())
+  {
+    return 1;
+  }
+
+  memc= memcached_create(NULL);
+
+  registry.add(memc_servers_set);
+  registry.add(memc_behavior_set);
+  registry.add(memc_behavior_get);
+  registry.add(memc_stats);
+  registry.add(memc_get);
+  registry.add(memc_get_by_key);
+  registry.add(memc_set);
+  registry.add(memc_set_by_key);
+  registry.add(memc_add);
+  registry.add(memc_add_by_key);
+  registry.add(memc_replace);
+  registry.add(memc_replace_by_key);
+  registry.add(memc_delete);
+  registry.add(memc_delete_by_key);
+  registry.add(memc_append);
+  registry.add(memc_append_by_key);
+  registry.add(memc_prepend);
+  registry.add(memc_prepend_by_key);
+  registry.add(memc_cas);
+  registry.add(memc_cas_by_key);
+  registry.add(memc_serv_count);
+  registry.add(memc_version);
+  registry.add(memc_increment);
+  registry.add(memc_decrement);
+
+  return 0;
+}
+
+static int memcachedDone(drizzled::plugin::Registry &registry)
+{
+  cleanupMemcUDF();
+
+  memcached_free(memc);
+
+  registry.remove(memc_servers_set);
+  registry.remove(memc_behavior_set);
+  registry.remove(memc_behavior_get);
+  registry.remove(memc_stats);
+  registry.remove(memc_get);
+  registry.remove(memc_get_by_key);
+  registry.remove(memc_set);
+  registry.remove(memc_set_by_key);
+  registry.remove(memc_add);
+  registry.remove(memc_add_by_key);
+  registry.remove(memc_replace);
+  registry.remove(memc_replace_by_key);
+  registry.remove(memc_delete);
+  registry.remove(memc_delete_by_key);
+  registry.remove(memc_append);
+  registry.remove(memc_append_by_key);
+  registry.remove(memc_prepend);
+  registry.remove(memc_prepend_by_key);
+  registry.remove(memc_cas);
+  registry.remove(memc_cas_by_key);
+  registry.remove(memc_serv_count);
+  registry.remove(memc_version);
+  registry.remove(memc_increment);
+  registry.remove(memc_decrement);
+
+  delete memc_servers_set;
+  delete memc_behavior_set;
+  delete memc_behavior_get;
+  delete memc_stats;
+  delete memc_get;
+  delete memc_get_by_key;
+  delete memc_set;
+  delete memc_set_by_key;
+  delete memc_add;
+  delete memc_add_by_key;
+  delete memc_replace;
+  delete memc_replace_by_key;
+  delete memc_delete;
+  delete memc_delete_by_key;
+  delete memc_append;
+  delete memc_append_by_key;
+  delete memc_prepend;
+  delete memc_prepend_by_key;
+  delete memc_cas;
+  delete memc_cas_by_key;
+  delete memc_serv_count;
+  delete memc_version;
+  delete memc_increment;
+  delete memc_decrement;
+
+  return 0;
+}
+
+drizzle_declare_plugin(memcached_functions)
+{
+  "memcached_functions",
+  "0.1",
+  "Patrick Galbraith, Ronald Bradford, Padraig O'Sullivan",
+  "Memcached UDF Plugin",
+  PLUGIN_LICENSE_GPL,
+  memcachedInit,
+  memcachedDone,
+  NULL,
+  NULL,
+  NULL
+}
+drizzle_declare_plugin_end;

=== added file 'plugin/memcached_functions/memcached_functions.h'
--- plugin/memcached_functions/memcached_functions.h	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/memcached_functions.h	2009-10-08 22:42:05 +0000
@@ -0,0 +1,52 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2009, Patrick "CaptTofu" Galbraith, Padraig O'Sullivan
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Patrick Galbraith nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#ifndef DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMCACHED_FUNCTIONS_H
+#define DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMCACHED_FUNCTIONS_H
+
+#include <libmemcached/memcached.h>
+
+extern memcached_st *memc;
+
+/**
+ * Initialize all the UDF functions for memcached.
+ *
+ * @return false on success; true on failure
+ */
+bool initMemcUDF();
+
+/**
+ * Release all memory allocated for the memcached
+ * UDF's.
+ */
+void cleanupMemcUDF();
+
+#endif /* DRIZZLE_PLUGIN_MEMCACHED_FUNCTIONS_MEMCACHED_FUNCTIONS_H */

=== added file 'plugin/memcached_functions/plugin.ac'
--- plugin/memcached_functions/plugin.ac	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/plugin.ac	2009-10-08 22:42:05 +0000
@@ -0,0 +1,9 @@
+AC_LIB_HAVE_LINKFLAGS(memcached,,
+  [#include <libmemcached/memcached.h>],
+  [
+    memcached_st memc;
+    memcached_lib_version();
+  ])
+AS_IF([test "x$ac_cv_libmemcached" = "xno"],
+      AC_MSG_WARN([libmemcached not found: not building memcached_functions plugin.]))
+DRIZZLED_PLUGIN_DEP_LIBS="${DRIZZLED_PLUGIN_DEP_LIBS} ${LTLIBMEMCACHED}"

=== added file 'plugin/memcached_functions/plugin.ini'
--- plugin/memcached_functions/plugin.ini	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/plugin.ini	2009-10-08 22:42:05 +0000
@@ -0,0 +1,34 @@
+[plugin]
+name=memcached_functions
+title=Memcached Client UDFs
+description=UDF plugin for libmemcached
+load_by_default=yes
+headers=memcached_functions.h 
+        memc_get.h memc_get_by_key.h
+        memc_set.h memc_set_by_key.h 
+        memc_add.h memc_add_by_key.h
+        memc_replace.h memc_replace_by_key.h
+        memc_delete.h memc_delete_by_key.h 
+        memc_append.h memc_append_by_key.h 
+        memc_prepend.h memc_prepend_by_key.h 
+        memc_cas.h memc_cas_by_key.h 
+        memc_misc.h 
+        memc_stats.h
+        memc_servers_set.h memc_behavior_set.h memc_behavior_get.h 
+        memc_increment.h memc_decrement.h
+sources=memcached_functions.cc 
+        memc_get.cc memc_get_by_key.cc 
+        memc_set.cc memc_set_by_key.cc 
+        memc_add.cc memc_add_by_key.cc
+        memc_replace.cc memc_replace_by_key.cc
+        memc_delete.cc memc_delete_by_key.cc 
+        memc_append.cc memc_append_by_key.cc 
+        memc_prepend.cc memc_prepend_by_key.cc 
+        memc_cas.cc memc_cas_by_key.cc 
+        memc_misc.cc memc_servers_set.cc
+        memc_behavior_set.cc memc_behavior_get.cc 
+        memc_increment.cc memc_decrement.cc
+        memc_stats.cc
+build_conditional="${ac_cv_libmemcached}" = "yes"
+ldflags=${LTLIBMEMCACHED}
+testsuite=memcached_functions

=== added directory 'plugin/memcached_functions/test'
=== added file 'plugin/memcached_functions/test/memc_test.expected'
--- plugin/memcached_functions/test/memc_test.expected	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/test/memc_test.expected	2009-10-08 22:42:05 +0000
@@ -0,0 +1,190 @@
+memc_servers_set('127.0.0.1:11211')
+SUCCESS
+memc_set('mysql:doc1', bcol)
+SUCCESS
+memc_get('mysql:doc1')
+This documentation is NOT distributed under a GPL license. Use of this documentation is subject to the following terms: You may create a printed copy of this documentation solely for your own personal use. Conversion to other formats is allowed as long as the actual content is not altered or edited in any way. You shall not publish or distribute this documentation in any form or on any media, except if you distribute the documentation in a manner similar to how MySQL disseminates it (that is, electronically for download on a Web site with the software) or on a CD-ROM or similar medium, provided however that the documentation is disseminated together with the software on the same medium. Any other use, such as any dissemination of printed copies or use of this documentation, in whole or in part, in another publication, requires the prior written consent from an authorized representative of MySQL AB. MySQL AB reserves any and all rights to this documentation not expressly granted above.
+memc_delete('mysql:doc1')
+SUCCESS
+memc_get('mysql:doc1')
+FAILURE
+memc_set('spot:test', ' Spot ')
+SUCCESS
+memc_get('spot:test')
+ Spot 
+memc_prepend('spot:test', 'See')
+SUCCESS
+memc_get('spot:test')
+See Spot 
+memc_append('spot:test', 'run.')
+SUCCESS
+memc_get('spot:test')
+See Spot run.
+memc_delete('spot:test')
+SUCCESS
+@behavior
+UNKNOWN BEHAVIOR TYPE!
+memc_behavior_set('MEMCACHED_BEHAVIOR_NO_BLOCK', '1')
+UNKNOWN BEHAVIOR TYPE!
+memc_behavior_get('MEMCACHED_BEHAVIOR_NO_BLOCK')
+UNKNOWN BEHAVIOR TYPE!
+memc_behavior_set('MEMCACHED_BEHAVIOR_NO_BLOCK', @behavior)
+UNKNOWN BEHAVIOR TYPE!
+@behavior
+0
+memc_behavior_set('MEMCACHED_BEHAVIOR_SUPPORT_CAS', '1')
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_SUPPORT_CAS')
+1
+memc_behavior_set('MEMCACHED_BEHAVIOR_SUPPORT_CAS', @behavior)
+SUCCESS
+memc_behavior_set('MEMCACHED_BEHAVIOR_TCP_NODELAY', '1')
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_TCP_NODELAY')
+1
+memc_behavior_set('MEMCACHED_BEHAVIOR_TCP_NODELAY', @behavior)
+SUCCESS
+memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', '1')
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS')
+1
+memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', @behavior)
+SUCCESS
+memc_behavior_set('MEMCACHED_BEHAVIOR_USER_DATA', '1')
+FAILURE
+memc_behavior_get('MEMCACHED_BEHAVIOR_USER_DATA')
+1
+memc_behavior_set('MEMCACHED_BEHAVIOR_USER_DATA', @behavior)
+FAILURE
+memc_behavior_set('MEMCACHED_BEHAVIOR_SORT_HOSTS', '1')
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_SORT_HOSTS')
+1
+memc_behavior_set('MEMCACHED_BEHAVIOR_SORT_HOSTS', @behavior)
+SUCCESS
+memc_behavior_set('MEMCACHED_BEHAVIOR_VERIFY_KEY', '1')
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_VERIFY_KEY')
+1
+memc_behavior_set('MEMCACHED_BEHAVIOR_VERIFY_KEY', @behavior)
+SUCCESS
+memc_behavior_set('MEMCACHED_BEHAVIOR_KETAMA', '1')
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_KETAMA')
+1
+memc_behavior_set('MEMCACHED_BEHAVIOR_CACHE_LOOKUPS', '1')
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_CACHE_LOOKUPS')
+1
+memc_behavior_set('MEMCACHED_BEHAVIOR_CACHE_LOOKUPS', @behavior)
+SUCCESS
+memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', '1')
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS')
+1
+memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', @behavior)
+SUCCESS
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_DEFAULT' )
+INVALID VALUE FOR MEMCACHED HASH ALGORITHM!
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_MD5
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_MD5' )
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_MD5
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_CRC' )
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_CRC
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1_64' )
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_FNV1_64
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1A_64' )
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_FNV1A_64
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1_32' )
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_FNV1_32
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1A_32' )
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_FNV1A_32
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_JENKINS' )
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_JENKINS
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_HSIEH' )
+FAILURE
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_JENKINS
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_MURMUR' )
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_MURMUR
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH', @preserve_behavior)
+SUCCESS
+memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', 'MEMCACHED_DISTRIBUTION_MODULA')
+INVALID VALUE FOR DISTRIBUTION!
+memc_behavior_get('MEMCACHED_BEHAVIOR_DISTRIBUTION')
+MEMCACHED_DISTRIBUTION_CONSISTENT_KETAMA
+memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', 'MEMCACHED_DISTRIBUTION_CONSISTENT')
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_DISTRIBUTION')
+MEMCACHED_DISTRIBUTION_CONSISTENT
+memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', 'MEMCACHED_DISTRIBUTION_CONSISTENT_KETAMA')
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_DISTRIBUTION')
+MEMCACHED_DISTRIBUTION_CONSISTENT_KETAMA
+memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', @preserve_dist)
+SUCCESS
+@size
+50748
+memc_behavior_set('MEMCACHED_BEHAVIOR_SOCKET_SEND_SIZE', 60000)
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_SOCKET_SEND_SIZE')
+50748
+memc_behavior_set('MEMCACHED_BEHAVIOR_SOCKET_SEND_SIZE', @size)
+SUCCESS
+@size
+87584
+memc_behavior_set('MEMCACHED_BEHAVIOR_SOCKET_RECV_SIZE', 120000)
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_SOCKET_RECV_SIZE')
+87584
+memc_behavior_set('MEMCACHED_BEHAVIOR_SOCKET_RECV_SIZE', @size)
+SUCCESS
+@size
+1000
+memc_behavior_set('MEMCACHED_BEHAVIOR_POLL_TIMEOUT', 100)
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_POLL_TIMEOUT')
+0
+memc_behavior_set('MEMCACHED_BEHAVIOR_POLL_TIMEOUT', @size)
+SUCCESS
+@size
+0
+memc_behavior_set('MEMCACHED_BEHAVIOR_RETRY_TIMEOUT', 5)
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_RETRY_TIMEOUT')
+0
+memc_behavior_set('MEMCACHED_BEHAVIOR_RETRY_TIMEOUT', @size)
+SUCCESS
+@size
+500
+memc_behavior_set('MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK', 5)
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK')
+0
+memc_behavior_set('MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK', @size)
+SUCCESS
+@size
+66560
+memc_behavior_set('MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK', 5)
+SUCCESS
+memc_behavior_get('MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK')
+0
+memc_behavior_set('MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK', @size)
+SUCCESS

=== added file 'plugin/memcached_functions/test/memc_test.sql'
--- plugin/memcached_functions/test/memc_test.sql	1970-01-01 00:00:00 +0000
+++ plugin/memcached_functions/test/memc_test.sql	2009-10-08 22:42:05 +0000
@@ -0,0 +1,168 @@
+# DROP FUNCTION IF EXISTS memc_servers_set;
+# DROP FUNCTION IF EXISTS memc_set;
+# DROP FUNCTION IF EXISTS memc_get;
+# DROP FUNCTION IF EXISTS memc_delete;
+# DROP FUNCTION IF EXISTS memc_append;
+# DROP FUNCTION IF EXISTS memc_prepend;
+# DROP FUNCTION IF EXISTS memc_behavior_set;
+# DROP FUNCTION IF EXISTS memc_behavior_get;
+# 
+# CREATE FUNCTION memc_servers_set RETURNS STRING SONAME "libmemcached_functions_mysql.so";
+# CREATE FUNCTION memc_set RETURNS STRING SONAME "libmemcached_functions_mysql.so";
+# CREATE FUNCTION memc_get RETURNS STRING SONAME "libmemcached_functions_mysql.so";
+# CREATE FUNCTION memc_delete RETURNS STRING SONAME "libmemcached_functions_mysql.so";
+# CREATE FUNCTION memc_append RETURNS STRING SONAME "libmemcached_functions_mysql.so";
+# CREATE FUNCTION memc_prepend RETURNS STRING SONAME "libmemcached_functions_mysql.so";
+# CREATE FUNCTION memc_behavior_set RETURNS STRING SONAME "libmemcached_functions_mysql.so";
+# CREATE FUNCTION memc_behavior_get RETURNS STRING SONAME "libmemcached_functions_mysql.so";
+
+DROP TABLE IF EXISTS `t1`;
+select memc_servers_set('127.0.0.1:11211');
+
+CREATE TABLE `t1` (id integer NOT NULL auto_increment primary key, bcol text);
+INSERT INTO `t1` (bcol) values ('This documentation is NOT distributed under a GPL license. Use of this documentation is subject to the following terms: You may create a printed copy of this documentation solely for your own personal use. Conversion to other formats is allowed as long as the actual content is not altered or edited in any way. You shall not publish or distribute this documentation in any form or on any media, except if you distribute the documentation in a manner similar to how MySQL disseminates it (that is, electronically for download on a Web site with the software) or on a CD-ROM or similar medium, provided however that the documentation is disseminated together with the software on the same medium. Any other use, such as any dissemination of printed copies or use of this documentation, in whole or in part, in another publication, requires the prior written consent from an authorized representative of MySQL AB. MySQL AB reserves any and all rights to this documentation not expressly granted above.');
+select memc_set('mysql:doc1', bcol) from t1;
+select memc_get('mysql:doc1');
+
+select memc_delete('mysql:doc1');
+select memc_get('mysql:doc1');
+
+select memc_set('spot:test', ' Spot ');
+select memc_get('spot:test');
+select memc_prepend('spot:test', 'See');
+select memc_get('spot:test');
+select memc_append('spot:test', 'run.');
+select memc_get('spot:test');
+select memc_delete('spot:test');
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_NO_BLOCK');
+select @behavior;
+select memc_behavior_set('MEMCACHED_BEHAVIOR_NO_BLOCK', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_NO_BLOCK');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_NO_BLOCK', @behavior);
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_SUPPORT_CAS');
+select @behavior;
+select memc_behavior_set('MEMCACHED_BEHAVIOR_SUPPORT_CAS', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_SUPPORT_CAS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_SUPPORT_CAS', @behavior);
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_TCP_NODELAY');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_TCP_NODELAY', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_TCP_NODELAY');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_TCP_NODELAY', @behavior);
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', @behavior);
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_USER_DATA');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_USER_DATA', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_USER_DATA');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_USER_DATA', @behavior);
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_SORT_HOSTS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_SORT_HOSTS', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_SORT_HOSTS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_SORT_HOSTS', @behavior);
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_VERIFY_KEY');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_VERIFY_KEY', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_VERIFY_KEY');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_VERIFY_KEY', @behavior);
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_KETAMA');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_KETAMA', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_KETAMA');
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_CACHE_LOOKUPS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_CACHE_LOOKUPS', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_CACHE_LOOKUPS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_CACHE_LOOKUPS', @behavior);
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', @behavior);
+
+set @preserve_behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_DEFAULT' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_MD5' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_CRC' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1_64' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1A_64' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1_32' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1A_32' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_JENKINS' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_HSIEH' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_MURMUR' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH', @preserve_behavior);
+
+set @preserve_dist= memc_behavior_get('MEMCACHED_BEHAVIOR_DISTRIBUTION');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', 'MEMCACHED_DISTRIBUTION_MODULA');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_DISTRIBUTION');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', 'MEMCACHED_DISTRIBUTION_CONSISTENT');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_DISTRIBUTION');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', 'MEMCACHED_DISTRIBUTION_CONSISTENT_KETAMA');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_DISTRIBUTION');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', @preserve_dist);
+
+set @size = memc_behavior_get('MEMCACHED_BEHAVIOR_SOCKET_SEND_SIZE');
+select @size;
+select memc_behavior_set('MEMCACHED_BEHAVIOR_SOCKET_SEND_SIZE', 60000);
+select memc_behavior_get('MEMCACHED_BEHAVIOR_SOCKET_SEND_SIZE');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_SOCKET_SEND_SIZE', @size);
+
+set @size = memc_behavior_get('MEMCACHED_BEHAVIOR_SOCKET_RECV_SIZE');
+select @size;
+select memc_behavior_set('MEMCACHED_BEHAVIOR_SOCKET_RECV_SIZE', 120000);
+select memc_behavior_get('MEMCACHED_BEHAVIOR_SOCKET_RECV_SIZE');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_SOCKET_RECV_SIZE', @size);
+
+set @size = memc_behavior_get('MEMCACHED_BEHAVIOR_POLL_TIMEOUT');
+select @size;
+select memc_behavior_set('MEMCACHED_BEHAVIOR_POLL_TIMEOUT', 100);
+select memc_behavior_get('MEMCACHED_BEHAVIOR_POLL_TIMEOUT');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_POLL_TIMEOUT', @size);
+
+
+set @size = memc_behavior_get('MEMCACHED_BEHAVIOR_RETRY_TIMEOUT');
+select @size;
+select memc_behavior_set('MEMCACHED_BEHAVIOR_RETRY_TIMEOUT', 5);
+select memc_behavior_get('MEMCACHED_BEHAVIOR_RETRY_TIMEOUT');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_RETRY_TIMEOUT', @size);
+
+set @size = memc_behavior_get('MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK');
+select @size;
+select memc_behavior_set('MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK', 5);
+select memc_behavior_get('MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK', @size);
+
+set @size = memc_behavior_get('MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK');
+select @size;
+select memc_behavior_set('MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK', 5);
+select memc_behavior_get('MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK', @size);

=== added directory 'tests/suite/memcached_functions'
=== added directory 'tests/suite/memcached_functions/r'
=== added file 'tests/suite/memcached_functions/r/memc.result'
--- tests/suite/memcached_functions/r/memc.result	1970-01-01 00:00:00 +0000
+++ tests/suite/memcached_functions/r/memc.result	2009-10-08 22:42:05 +0000
@@ -0,0 +1,417 @@
+DROP TABLE IF EXISTS `t1`;
+Warnings:
+Note	1051	Unknown table 't1'
+select memc_servers_set('127.0.0.1:19191');
+memc_servers_set('127.0.0.1:19191')
+1
+CREATE TABLE `t1` (id integer NOT NULL auto_increment primary key, bcol text);
+INSERT INTO `t1` (bcol) values ('This documentation is NOT distributed under a GPL license. Use of this documentation is subject to the following terms: You may create a printed copy of this documentation solely for your own personal use. Conversion to other formats is allowed as long as the actual content is not altered or edited in any way. You shall not publish or distribute this documentation in any form or on any media, except if you distribute the documentation in a manner similar to how MySQL disseminates it (that is, electronically for download on a Web site with the software) or on a CD-ROM or similar medium, provided however that the documentation is disseminated together with the software on the same medium. Any other use, such as any dissemination of printed copies or use of this documentation, in whole or in part, in another publication, requires the prior written consent from an authorized representative of MySQL AB. MySQL AB reserves any and all rights to this documentation not expressly granted above.');
+select memc_set('mysql:doc1', bcol) from t1;
+memc_set('mysql:doc1', bcol)
+1
+select memc_get('mysql:doc1');
+memc_get('mysql:doc1')
+This documentation is NOT distributed under a GPL license. Use of this documentation is subject to the following terms: You may create a printed copy of this documentation solely for your own personal use. Conversion to other formats is allowed as long as the actual content is not altered or edited in any way. You shall not publish or distribute this documentation in any form or on any media, except if you distribute the documentation in a manner similar to how MySQL disseminates it (that is, electronically for download on a Web site with the software) or on a CD-ROM or similar medium, provided however that the documentation is disseminated together with the software on the same medium. Any other use, such as any dissemination of printed copies or use of this documentation, in whole or in part, in another publication, requires the prior written consent from an authorized representative of MySQL AB. MySQL AB reserves any and all rights to this documentation not expressly granted above.
+select memc_delete('mysql:doc1');
+memc_delete('mysql:doc1')
+1
+select memc_get('mysql:doc1');
+memc_get('mysql:doc1')
+NULL
+select memc_set('spot:test', ' Spot ');
+memc_set('spot:test', ' Spot ')
+1
+select memc_get('spot:test');
+memc_get('spot:test')
+ Spot 
+select memc_prepend('spot:test', 'See');
+memc_prepend('spot:test', 'See')
+1
+select memc_get('spot:test');
+memc_get('spot:test')
+See Spot 
+select memc_append('spot:test', 'run.');
+memc_append('spot:test', 'run.')
+1
+select memc_get('spot:test');
+memc_get('spot:test')
+See Spot run.
+select memc_delete('spot:test');
+memc_delete('spot:test')
+1
+select memc_set('increment:test', 1);
+memc_set('increment:test', 1)
+1
+select memc_get('increment:test');
+memc_get('increment:test')
+1
+select memc_increment('increment:test');
+memc_increment('increment:test')
+2
+select memc_get('increment:test');
+memc_get('increment:test')
+2
+select memc_increment('increment:test', 5);
+memc_increment('increment:test', 5)
+7
+select memc_get('increment:test');
+memc_get('increment:test')
+7
+select memc_increment('increment:test', 20);
+memc_increment('increment:test', 20)
+27
+select memc_get('increment:test');
+memc_get('increment:test')
+27
+select memc_decrement('increment:test', 20);
+memc_decrement('increment:test', 20)
+7
+select memc_get('increment:test');
+memc_get('increment:test')
+7 
+select memc_decrement('increment:test');
+memc_decrement('increment:test')
+6
+select memc_get('increment:test');
+memc_get('increment:test')
+6 
+select memc_delete('increment:test');
+memc_delete('increment:test')
+1
+select memc_set('this_should_expire', '10 seconds', 10);
+memc_set('this_should_expire', '10 seconds', 10)
+1
+select memc_get('this_should_expire');
+memc_get('this_should_expire')
+10 seconds
+select sleep(5);
+sleep(5)
+0
+select memc_get('this_should_expire');
+memc_get('this_should_expire')
+10 seconds
+select sleep(6);
+sleep(6)
+0
+select memc_get('this_should_expire');
+memc_get('this_should_expire')
+NULL
+select memc_set('add:test', 'someval');
+memc_set('add:test', 'someval')
+1
+select memc_add('add:test', 'someval');
+memc_add('add:test', 'someval')
+0
+select memc_delete('add:test');
+memc_delete('add:test')
+1
+select memc_add('add:test', 'someval');
+memc_add('add:test', 'someval')
+1
+select memc_get('add:test');
+memc_get('add:test')
+someval
+select memc_delete('add:test');
+memc_delete('add:test')
+1
+select memc_add('add:test', 'someval');
+memc_add('add:test', 'someval')
+1
+select memc_get('add:test');
+memc_get('add:test')
+someval
+select memc_replace('replace:test', 'replaced');
+memc_replace('replace:test', 'replaced')
+0
+select memc_set('replace:test', 'initial');
+memc_set('replace:test', 'initial')
+1
+select memc_get('replace:test');
+memc_get('replace:test')
+initial
+select memc_replace('replace:test', 'replaced');
+memc_replace('replace:test', 'replaced')
+1
+select memc_get('replace:test');
+memc_get('replace:test')
+replaced
+select memc_replace('replace:test', 'replaced again');
+memc_replace('replace:test', 'replaced again')
+1
+select memc_get('replace:test');
+memc_get('replace:test')
+replaced again
+select memc_delete('replace:test');
+memc_delete('replace:test')
+1
+select memc_add_by_key('A', 'add:test', 'someval');
+memc_add_by_key('A', 'add:test', 'someval')
+0
+select memc_get_by_key('A', 'add:test');
+memc_get_by_key('A', 'add:test')
+someval
+select memc_set_by_key('A', 'replace:test', 'initial');
+memc_set_by_key('A', 'replace:test', 'initial')
+1
+select memc_get_by_key('A', 'replace:test');
+memc_get_by_key('A', 'replace:test')
+initial
+select memc_add_by_key('A', 'add:test', 'someotherval');
+memc_add_by_key('A', 'add:test', 'someotherval')
+0
+select memc_get_by_key('A', 'add:test');
+memc_get_by_key('A', 'add:test')
+someval
+select memc_replace_by_key('A', 'replace:test', 'replaced');
+memc_replace_by_key('A', 'replace:test', 'replaced')
+1
+select memc_get_by_key('A', 'replace:test');
+memc_get_by_key('A', 'replace:test')
+replaced
+select memc_delete_by_key('A', 'replace:test');
+memc_delete_by_key('A', 'replace:test')
+0
+select memc_get_by_key('A', 'replace:test');
+memc_get_by_key('A', 'replace:test')
+replaced
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_NO_BLOCK');
+select @behavior;
+@behavior
+0
+select memc_behavior_set('MEMCACHED_BEHAVIOR_NO_BLOCK', '1');
+memc_behavior_set('MEMCACHED_BEHAVIOR_NO_BLOCK', '1')
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_NO_BLOCK');
+memc_behavior_get('MEMCACHED_BEHAVIOR_NO_BLOCK')
+1
+select memc_behavior_set('MEMCACHED_BEHAVIOR_NO_BLOCK', @behavior);
+memc_behavior_set('MEMCACHED_BEHAVIOR_NO_BLOCK', @behavior)
+1
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_SUPPORT_CAS');
+select @behavior;
+@behavior
+0
+select memc_behavior_set('MEMCACHED_BEHAVIOR_SUPPORT_CAS', '1');
+memc_behavior_set('MEMCACHED_BEHAVIOR_SUPPORT_CAS', '1')
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_SUPPORT_CAS');
+memc_behavior_get('MEMCACHED_BEHAVIOR_SUPPORT_CAS')
+1
+select memc_behavior_set('MEMCACHED_BEHAVIOR_SUPPORT_CAS', @behavior);
+memc_behavior_set('MEMCACHED_BEHAVIOR_SUPPORT_CAS', @behavior)
+1
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_TCP_NODELAY');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_TCP_NODELAY', '1');
+memc_behavior_set('MEMCACHED_BEHAVIOR_TCP_NODELAY', '1')
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_TCP_NODELAY');
+memc_behavior_get('MEMCACHED_BEHAVIOR_TCP_NODELAY')
+1
+select memc_behavior_set('MEMCACHED_BEHAVIOR_TCP_NODELAY', @behavior);
+memc_behavior_set('MEMCACHED_BEHAVIOR_TCP_NODELAY', @behavior)
+1
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', '1');
+memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', '1')
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS');
+memc_behavior_get('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS')
+1
+select memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', @behavior);
+memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', @behavior)
+1
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_USER_DATA');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_USER_DATA', '1');
+memc_behavior_set('MEMCACHED_BEHAVIOR_USER_DATA', '1')
+0
+select memc_behavior_get('MEMCACHED_BEHAVIOR_USER_DATA');
+memc_behavior_get('MEMCACHED_BEHAVIOR_USER_DATA')
+1
+select memc_behavior_set('MEMCACHED_BEHAVIOR_USER_DATA', @behavior);
+memc_behavior_set('MEMCACHED_BEHAVIOR_USER_DATA', @behavior)
+0
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_SORT_HOSTS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_SORT_HOSTS', '1');
+memc_behavior_set('MEMCACHED_BEHAVIOR_SORT_HOSTS', '1')
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_SORT_HOSTS');
+memc_behavior_get('MEMCACHED_BEHAVIOR_SORT_HOSTS')
+1
+select memc_behavior_set('MEMCACHED_BEHAVIOR_SORT_HOSTS', @behavior);
+memc_behavior_set('MEMCACHED_BEHAVIOR_SORT_HOSTS', @behavior)
+1
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_VERIFY_KEY');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_VERIFY_KEY', '1');
+memc_behavior_set('MEMCACHED_BEHAVIOR_VERIFY_KEY', '1')
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_VERIFY_KEY');
+memc_behavior_get('MEMCACHED_BEHAVIOR_VERIFY_KEY')
+1
+select memc_behavior_set('MEMCACHED_BEHAVIOR_VERIFY_KEY', @behavior);
+memc_behavior_set('MEMCACHED_BEHAVIOR_VERIFY_KEY', @behavior)
+1
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_KETAMA');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_KETAMA', '1');
+memc_behavior_set('MEMCACHED_BEHAVIOR_KETAMA', '1')
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_KETAMA');
+memc_behavior_get('MEMCACHED_BEHAVIOR_KETAMA')
+1
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_CACHE_LOOKUPS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_CACHE_LOOKUPS', '1');
+memc_behavior_set('MEMCACHED_BEHAVIOR_CACHE_LOOKUPS', '1')
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_CACHE_LOOKUPS');
+memc_behavior_get('MEMCACHED_BEHAVIOR_CACHE_LOOKUPS')
+1
+select memc_behavior_set('MEMCACHED_BEHAVIOR_CACHE_LOOKUPS', @behavior);
+memc_behavior_set('MEMCACHED_BEHAVIOR_CACHE_LOOKUPS', @behavior)
+1
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', '1');
+memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', '1')
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS');
+memc_behavior_get('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS')
+1
+select memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', @behavior);
+memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', @behavior)
+1
+set @preserve_behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_DEFAULT' );
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_DEFAULT' )
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_DEFAULT
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_MD5' );
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_MD5' )
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_MD5
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_CRC' );
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_CRC' )
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_CRC
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1_64' );
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1_64' )
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_FNV1_64
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1A_64' );
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1A_64' )
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_FNV1A_64
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1_32' );
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1_32' )
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_FNV1_32
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1A_32' );
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1A_32' )
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_FNV1A_32
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_JENKINS' );
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_JENKINS' )
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_JENKINS
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_HSIEH' );
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_HSIEH' )
+0
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_JENKINS
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_MURMUR' );
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_MURMUR' )
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+memc_behavior_get('MEMCACHED_BEHAVIOR_HASH')
+MEMCACHED_HASH_MURMUR
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH', @preserve_behavior);
+memc_behavior_set('MEMCACHED_BEHAVIOR_HASH', @preserve_behavior)
+1
+set @preserve_dist= memc_behavior_get('MEMCACHED_BEHAVIOR_DISTRIBUTION');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', 'MEMCACHED_DISTRIBUTION_MODULA');
+memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', 'MEMCACHED_DISTRIBUTION_MODULA')
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_DISTRIBUTION');
+memc_behavior_get('MEMCACHED_BEHAVIOR_DISTRIBUTION')
+MEMCACHED_DISTRIBUTION_MODULA
+select memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', 'MEMCACHED_DISTRIBUTION_CONSISTENT');
+memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', 'MEMCACHED_DISTRIBUTION_CONSISTENT')
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_DISTRIBUTION');
+memc_behavior_get('MEMCACHED_BEHAVIOR_DISTRIBUTION')
+MEMCACHED_DISTRIBUTION_CONSISTENT
+select memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', 'MEMCACHED_DISTRIBUTION_CONSISTENT_KETAMA');
+memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', 'MEMCACHED_DISTRIBUTION_CONSISTENT_KETAMA')
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_DISTRIBUTION');
+memc_behavior_get('MEMCACHED_BEHAVIOR_DISTRIBUTION')
+MEMCACHED_DISTRIBUTION_CONSISTENT_KETAMA
+select memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', @preserve_dist);
+memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', @preserve_dist)
+1
+set @size = memc_behavior_get('MEMCACHED_BEHAVIOR_POLL_TIMEOUT');
+select @size;
+@size
+1000
+select memc_behavior_set('MEMCACHED_BEHAVIOR_POLL_TIMEOUT', 100);
+memc_behavior_set('MEMCACHED_BEHAVIOR_POLL_TIMEOUT', 100)
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_POLL_TIMEOUT');
+memc_behavior_get('MEMCACHED_BEHAVIOR_POLL_TIMEOUT')
+0
+select memc_behavior_set('MEMCACHED_BEHAVIOR_POLL_TIMEOUT', @size);
+memc_behavior_set('MEMCACHED_BEHAVIOR_POLL_TIMEOUT', @size)
+1
+set @size = memc_behavior_get('MEMCACHED_BEHAVIOR_RETRY_TIMEOUT');
+select @size;
+@size
+0
+select memc_behavior_set('MEMCACHED_BEHAVIOR_RETRY_TIMEOUT', 5);
+memc_behavior_set('MEMCACHED_BEHAVIOR_RETRY_TIMEOUT', 5)
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_RETRY_TIMEOUT');
+memc_behavior_get('MEMCACHED_BEHAVIOR_RETRY_TIMEOUT')
+0
+select memc_behavior_set('MEMCACHED_BEHAVIOR_RETRY_TIMEOUT', @size);
+memc_behavior_set('MEMCACHED_BEHAVIOR_RETRY_TIMEOUT', @size)
+1
+set @size = memc_behavior_get('MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK');
+select @size;
+@size
+500
+select memc_behavior_set('MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK', 5);
+memc_behavior_set('MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK', 5)
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK');
+memc_behavior_get('MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK')
+0
+select memc_behavior_set('MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK', @size);
+memc_behavior_set('MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK', @size)
+1
+set @size = memc_behavior_get('MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK');
+select @size;
+@size
+66560
+select memc_behavior_set('MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK', 5);
+memc_behavior_set('MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK', 5)
+1
+select memc_behavior_get('MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK');
+memc_behavior_get('MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK')
+0
+select memc_behavior_set('MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK', @size);
+memc_behavior_set('MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK', @size)
+1

=== added file 'tests/suite/memcached_functions/start_mc.sh'
--- tests/suite/memcached_functions/start_mc.sh	1970-01-01 00:00:00 +0000
+++ tests/suite/memcached_functions/start_mc.sh	2009-10-08 22:42:05 +0000
@@ -0,0 +1,48 @@
+#! /bin/sh
+
+PORT=19191
+if [ $MC_PORT ]; then
+  PORT=$MC_PORT
+fi
+
+USER=nobody
+MAXCONN=1024
+CACHESIZE=1024
+OPTIONS=""
+
+PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin:$PATH
+RETVAL=0
+
+start () {
+	memcached -d -p $PORT -u $USER -m $CACHESIZE -c $MAXCONN -U 0
+	RETVAL=$?
+}
+stop () {
+	kill -9 `ps -ef | grep memcached | grep $PORT | grep $USER | grep -v grep | awk '{print $2}'`
+        RETVAL=$?
+}
+
+restart () {
+        stop
+        start
+}
+
+
+# See how we were called.
+case "$1" in
+  start)
+        start
+        ;;
+  stop)
+        stop
+        ;;
+  restart|reload)
+        restart
+        ;;
+  *)
+        echo $"Usage: $0 {start|stop|restart|reload}"
+        exit 1
+esac
+
+exit $?
+

=== added directory 'tests/suite/memcached_functions/t'
=== added file 'tests/suite/memcached_functions/t/memc.test'
--- tests/suite/memcached_functions/t/memc.test	1970-01-01 00:00:00 +0000
+++ tests/suite/memcached_functions/t/memc.test	2009-10-08 22:42:05 +0000
@@ -0,0 +1,194 @@
+# we are assuming the memcached binary is contained in PATH or
+# common directories we might expect it to be in
+--exec ./suite/memcached_functions/start_mc.sh start
+
+DROP TABLE IF EXISTS `t1`;
+select memc_servers_set('127.0.0.1:19191');
+
+CREATE TABLE `t1` (id integer NOT NULL auto_increment primary key, bcol text);
+INSERT INTO `t1` (bcol) values ('This documentation is NOT distributed under a GPL license. Use of this documentation is subject to the following terms: You may create a printed copy of this documentation solely for your own personal use. Conversion to other formats is allowed as long as the actual content is not altered or edited in any way. You shall not publish or distribute this documentation in any form or on any media, except if you distribute the documentation in a manner similar to how MySQL disseminates it (that is, electronically for download on a Web site with the software) or on a CD-ROM or similar medium, provided however that the documentation is disseminated together with the software on the same medium. Any other use, such as any dissemination of printed copies or use of this documentation, in whole or in part, in another publication, requires the prior written consent from an authorized representative of MySQL AB. MySQL AB reserves any and all rights to this documentation not expressly granted above.');
+select memc_set('mysql:doc1', bcol) from t1;
+select memc_get('mysql:doc1');
+
+select memc_delete('mysql:doc1');
+select memc_get('mysql:doc1');
+
+select memc_set('spot:test', ' Spot ');
+select memc_get('spot:test');
+select memc_prepend('spot:test', 'See');
+select memc_get('spot:test');
+select memc_append('spot:test', 'run.');
+select memc_get('spot:test');
+select memc_delete('spot:test');
+
+select memc_set('increment:test', 1);
+select memc_get('increment:test');
+select memc_increment('increment:test');
+select memc_get('increment:test');
+select memc_increment('increment:test', 5);
+select memc_get('increment:test');
+select memc_increment('increment:test', 20);
+select memc_get('increment:test');
+select memc_decrement('increment:test', 20);
+select memc_get('increment:test');
+select memc_decrement('increment:test');
+select memc_get('increment:test');
+select memc_delete('increment:test');
+
+select memc_set('this_should_expire', '10 seconds', 10);
+select memc_get('this_should_expire');
+select sleep(5);
+select memc_get('this_should_expire');
+select sleep(6);
+select memc_get('this_should_expire');
+
+select memc_set('add:test', 'someval');
+select memc_add('add:test', 'someval');
+select memc_delete('add:test');
+select memc_add('add:test', 'someval');
+select memc_get('add:test');
+select memc_delete('add:test');
+
+select memc_add('add:test', 'someval');
+select memc_get('add:test');
+select memc_replace('replace:test', 'replaced');
+select memc_set('replace:test', 'initial');
+select memc_get('replace:test');
+select memc_replace('replace:test', 'replaced');
+select memc_get('replace:test');
+select memc_replace('replace:test', 'replaced again');
+select memc_get('replace:test');
+select memc_delete('replace:test');
+
+select memc_add_by_key('A', 'add:test', 'someval');
+select memc_get_by_key('A', 'add:test');
+select memc_set_by_key('A', 'replace:test', 'initial');
+select memc_get_by_key('A', 'replace:test');
+select memc_add_by_key('A', 'add:test', 'someotherval');
+select memc_get_by_key('A', 'add:test');
+select memc_replace_by_key('A', 'replace:test', 'replaced');
+select memc_get_by_key('A', 'replace:test');
+select memc_delete_by_key('A', 'replace:test');
+select memc_get_by_key('A', 'replace:test');
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_NO_BLOCK');
+select @behavior;
+select memc_behavior_set('MEMCACHED_BEHAVIOR_NO_BLOCK', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_NO_BLOCK');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_NO_BLOCK', @behavior);
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_SUPPORT_CAS');
+select @behavior;
+select memc_behavior_set('MEMCACHED_BEHAVIOR_SUPPORT_CAS', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_SUPPORT_CAS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_SUPPORT_CAS', @behavior);
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_TCP_NODELAY');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_TCP_NODELAY', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_TCP_NODELAY');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_TCP_NODELAY', @behavior);
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', @behavior);
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_USER_DATA');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_USER_DATA', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_USER_DATA');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_USER_DATA', @behavior);
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_SORT_HOSTS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_SORT_HOSTS', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_SORT_HOSTS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_SORT_HOSTS', @behavior);
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_VERIFY_KEY');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_VERIFY_KEY', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_VERIFY_KEY');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_VERIFY_KEY', @behavior);
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_KETAMA');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_KETAMA', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_KETAMA');
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_CACHE_LOOKUPS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_CACHE_LOOKUPS', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_CACHE_LOOKUPS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_CACHE_LOOKUPS', @behavior);
+
+set @behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', '1');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_BUFFER_REQUESTS', @behavior);
+
+set @preserve_behavior = memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_DEFAULT' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_MD5' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_CRC' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1_64' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1A_64' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1_32' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_FNV1A_32' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_JENKINS' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_HSIEH' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH','MEMCACHED_HASH_MURMUR' );
+select memc_behavior_get('MEMCACHED_BEHAVIOR_HASH');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_HASH', @preserve_behavior);
+
+set @preserve_dist= memc_behavior_get('MEMCACHED_BEHAVIOR_DISTRIBUTION');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', 'MEMCACHED_DISTRIBUTION_MODULA');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_DISTRIBUTION');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', 'MEMCACHED_DISTRIBUTION_CONSISTENT');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_DISTRIBUTION');
+
+select memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', 'MEMCACHED_DISTRIBUTION_CONSISTENT_KETAMA');
+select memc_behavior_get('MEMCACHED_BEHAVIOR_DISTRIBUTION');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_DISTRIBUTION', @preserve_dist);
+
+set @size = memc_behavior_get('MEMCACHED_BEHAVIOR_POLL_TIMEOUT');
+select @size;
+select memc_behavior_set('MEMCACHED_BEHAVIOR_POLL_TIMEOUT', 100);
+select memc_behavior_get('MEMCACHED_BEHAVIOR_POLL_TIMEOUT');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_POLL_TIMEOUT', @size);
+
+
+set @size = memc_behavior_get('MEMCACHED_BEHAVIOR_RETRY_TIMEOUT');
+select @size;
+select memc_behavior_set('MEMCACHED_BEHAVIOR_RETRY_TIMEOUT', 5);
+select memc_behavior_get('MEMCACHED_BEHAVIOR_RETRY_TIMEOUT');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_RETRY_TIMEOUT', @size);
+
+set @size = memc_behavior_get('MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK');
+select @size;
+select memc_behavior_set('MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK', 5);
+select memc_behavior_get('MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_IO_MSG_WATERMARK', @size);
+
+set @size = memc_behavior_get('MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK');
+select @size;
+select memc_behavior_set('MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK', 5);
+select memc_behavior_get('MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK');
+select memc_behavior_set('MEMCACHED_BEHAVIOR_IO_BYTES_WATERMARK', @size);
+
+--exec ./suite/memcached_functions/start_mc.sh stop

